/*
 * File: pci_vendors.h
 * This file was generated automatically. Don't modify it.
*/
#ifndef PCI_VENDORS_INCLUDED
#define PCI_VENDORS_INCLUDED 1

#define VENDOR_GAMMAGRAPHX	0x0000 /*Gammagraphx, Inc.*/
#define VENDOR_ASCEND		0x001a /*Ascend Communications, Inc.*/
#define VENDOR_PARADYNE		0x0033 /*Paradyne corp.*/
#define VENDOR_LOCKHEED		0x003d /*Lockheed Martin-Marietta Corp*/
#define VENDOR_TIGER		0x0059 /*Tiger Jet Network Inc. (Wrong ID)*/
#define VENDOR_HAUPPAUGE	0x0070 /*Hauppauge computer works Inc.*/
#define VENDOR_NEBULA		0x0071 /*Nebula Electronics Ltd.*/
#define VENDOR_SILICON		0x0095 /*Silicon Image, Inc. (Wrong ID)*/
#define VENDOR_NCIPHER		0x0100 /*Ncipher Corp Ltd*/
#define VENDOR_LEVELONE		0x018a /*LevelOne*/
#define VENDOR_COMPAQ		0x021b /*Compaq Computer Corporation*/
#define VENDOR_DAVICOM		0x0291 /*Davicom Semiconductor, Inc.*/
#define VENDOR_SPEEDSTREAM	0x02ac /*SpeedStream*/
#define VENDOR_TTTECH		0x0357 /*TTTech AG*/
#define VENDOR_CYBERDOOR	0x05e3 /*CyberDoor*/
#define VENDOR_DYNALINK		0x0675 /*Dynalink*/
#define VENDOR_VIA		0x0925 /*VIA Technologies, Inc. (Wrong ID)*/
#define VENDOR_ARRIS		0x09c1 /*Arris*/
#define VENDOR_BREA		0x0a89 /*BREA Technologies Inc*/
#define VENDOR_ASCII		0x0b49 /*ASCII Corporation*/
#define VENDOR_COMPAQ2		0x0e11 /*Compaq Computer Corporation*/
#define VENDOR_HASOTEC		0x0e55 /*HaSoTec GmbH*/
#define VENDOR_LSI		0x1000 /*LSI Logic / Symbios Logic*/
#define VENDOR_KOLTER		0x1001 /*Kolter Electronic*/
#define VENDOR_ATI		0x1002 /*ATI Technologies Inc*/
#define VENDOR_ULSI		0x1003 /*ULSI Systems*/
#define VENDOR_VLSI		0x1004 /*VLSI Technology Inc*/
#define VENDOR_AVANCE		0x1005 /*Avance Logic Inc. [ALI]*/
#define VENDOR_REPLY		0x1006 /*Reply Group*/
#define VENDOR_NETFRAME		0x1007 /*NetFrame Systems Inc*/
#define VENDOR_EPSON		0x1008 /*Epson*/
#define VENDOR_PHOENIX		0x100a /*Phoenix Technologies*/
#define VENDOR_NATIONAL		0x100b /*National Semiconductor Corporation*/
#define VENDOR_TSENG		0x100c /*Tseng Labs Inc*/
#define VENDOR_AST		0x100d /*AST Research Inc*/
#define VENDOR_WEITEK		0x100e /*Weitek*/
#define VENDOR_VIDEO		0x1010 /*Video Logic, Ltd.*/
#define VENDOR_DIGITAL		0x1011 /*Digital Equipment Corporation*/
#define VENDOR_MICRONICS	0x1012 /*Micronics Computers Inc*/
#define VENDOR_CIRRUS		0x1013 /*Cirrus Logic*/
#define VENDOR_IBM		0x1014 /*IBM*/
#define VENDOR_LSI2		0x1015 /*LSI Logic Corp of Canada*/
#define VENDOR_ICL		0x1016 /*ICL Personal Systems*/
#define VENDOR_SPEA		0x1017 /*SPEA Software AG*/
#define VENDOR_UNISYS		0x1018 /*Unisys Systems*/
#define VENDOR_ELITEGROUP	0x1019 /*Elitegroup Computer Systems*/
#define VENDOR_AT_T		0x101a /*AT&T GIS (NCR)*/
#define VENDOR_VITESSE		0x101b /*Vitesse Semiconductor*/
#define VENDOR_WESTERN		0x101c /*Western Digital*/
#define VENDOR_AMERICAN		0x101e /*American Megatrends Inc.*/
#define VENDOR_PICTURETEL	0x101f /*PictureTel*/
#define VENDOR_HITACHI		0x1020 /*Hitachi Computer Products*/
#define VENDOR_OKI		0x1021 /*OKI Electric Industry Co. Ltd.*/
#define VENDOR_ADVANCED		0x1022 /*Advanced Micro Devices [AMD]*/
#define VENDOR_TRIDENT		0x1023 /*Trident Microsystems*/
#define VENDOR_ZENITH		0x1024 /*Zenith Data Systems*/
#define VENDOR_ACER		0x1025 /*Acer Incorporated [ALI]*/
#define VENDOR_DELL		0x1028 /*Dell*/
#define VENDOR_SIEMENS		0x1029 /*Siemens Nixdorf IS*/
#define VENDOR_LSI3		0x102a /*LSI Logic*/
#define VENDOR_MATROX		0x102b /*Matrox Graphics, Inc.*/
#define VENDOR_CHIPS		0x102c /*Chips and Technologies*/
#define VENDOR_WYSE		0x102d /*Wyse Technology Inc.*/
#define VENDOR_OLIVETTI		0x102e /*Olivetti Advanced Technology*/
#define VENDOR_TOSHIBA		0x102f /*Toshiba America*/
#define VENDOR_TMC		0x1030 /*TMC Research*/
#define VENDOR_MIRO		0x1031 /*Miro Computer Products AG*/
#define VENDOR_COMPAQ3		0x1032 /*Compaq*/
#define VENDOR_NEC		0x1033 /*NEC Corporation*/
#define VENDOR_FRAMATOME	0x1034 /*Framatome Connectors USA Inc.*/
#define VENDOR_COMP		0x1035 /*Comp. & Comm. Research Lab*/
#define VENDOR_FUTURE		0x1036 /*Future Domain Corp.*/
#define VENDOR_HITACHI2		0x1037 /*Hitachi Micro Systems*/
#define VENDOR_AMP		0x1038 /*AMP, Inc*/
#define VENDOR_SILICON2		0x1039 /*Silicon Integrated Systems [SiS]*/
#define VENDOR_SEIKO		0x103a /*Seiko Epson Corporation*/
#define VENDOR_TATUNG		0x103b /*Tatung Co. of America*/
#define VENDOR_HEWLETT_PACKARD	0x103c /*Hewlett-Packard Company*/
#define VENDOR_SOLLIDAY		0x103e /*Solliday Engineering*/
#define VENDOR_SYNOPSYS_LOGIC	0x103f /*Synopsys/Logic Modeling Group*/
#define VENDOR_ACCELGRAPHICS	0x1040 /*Accelgraphics Inc.*/
#define VENDOR_COMPUTREND	0x1041 /*Computrend*/
#define VENDOR_MICRON		0x1042 /*Micron*/
#define VENDOR_ASUSTEK		0x1043 /*ASUSTeK Computer Inc.*/
#define VENDOR_ADAPTEC		0x1044 /*Adaptec (formerly DPT)*/
#define VENDOR_OPTI		0x1045 /*OPTi Inc.*/
#define VENDOR_IPC		0x1046 /*IPC Corporation, Ltd.*/
#define VENDOR_GENOA		0x1047 /*Genoa Systems Corp*/
#define VENDOR_ELSA		0x1048 /*Elsa AG*/
#define VENDOR_FOUNTAIN		0x1049 /*Fountain Technologies, Inc.*/
#define VENDOR_STMICROELECTRONICS	0x104a /*STMicroelectronics*/
#define VENDOR_BUSLOGIC		0x104b /*BusLogic*/
#define VENDOR_TEXAS		0x104c /*Texas Instruments*/
#define VENDOR_SONY		0x104d /*Sony Corporation*/
#define VENDOR_OAK		0x104e /*Oak Technology, Inc*/
#define VENDOR_CO_TIME		0x104f /*Co-time Computer Ltd*/
#define VENDOR_WINBOND		0x1050 /*Winbond Electronics Corp*/
#define VENDOR_ANIGMA		0x1051 /*Anigma, Inc.*/
#define VENDOR__YOUNG		0x1052 /*?Young Micro Systems*/
#define VENDOR_YOUNG		0x1053 /*Young Micro Systems*/
#define VENDOR_HITACHI3		0x1054 /*Hitachi, Ltd*/
#define VENDOR_EFAR		0x1055 /*Efar Microsystems*/
#define VENDOR_ICL2		0x1056 /*ICL*/
#define VENDOR_MOTOROLA		0x1057 /*Motorola*/
#define VENDOR_ELECTRONICS	0x1058 /*Electronics & Telecommunications RSH*/
#define VENDOR_TEKNOR		0x1059 /*Teknor Industrial Computers Inc*/
#define VENDOR_PROMISE		0x105a /*Promise Technology, Inc.*/
#define VENDOR_FOXCONN		0x105b /*Foxconn International, Inc.*/
#define VENDOR_WIPRO		0x105c /*Wipro Infotech Limited*/
#define VENDOR_NUMBER		0x105d /*Number 9 Computer Company*/
#define VENDOR_VTECH		0x105e /*Vtech Computers Ltd*/
#define VENDOR_INFOTRONIC	0x105f /*Infotronic America Inc*/
#define VENDOR_UNITED		0x1060 /*United Microelectronics [UMC]*/
#define VENDOR_I_I_T		0x1061 /*I.I.T.*/
#define VENDOR_MASPAR		0x1062 /*Maspar Computer Corp*/
#define VENDOR_OCEAN		0x1063 /*Ocean Office Automation*/
#define VENDOR_ALCATEL		0x1064 /*Alcatel*/
#define VENDOR_TEXAS2		0x1065 /*Texas Microsystems*/
#define VENDOR_PICOPOWER	0x1066 /*PicoPower Technology*/
#define VENDOR_MITSUBISHI	0x1067 /*Mitsubishi Electric*/
#define VENDOR_DIVERSIFIED	0x1068 /*Diversified Technology*/
#define VENDOR_MYLEX		0x1069 /*Mylex Corporation*/
#define VENDOR_ATEN		0x106a /*Aten Research Inc*/
#define VENDOR_APPLE		0x106b /*Apple Computer Inc.*/
#define VENDOR_HYNIX		0x106c /*Hynix Semiconductor*/
#define VENDOR_SEQUENT		0x106d /*Sequent Computer Systems*/
#define VENDOR_DFI		0x106e /*DFI, Inc*/
#define VENDOR_CITY		0x106f /*City Gate Development Ltd*/
#define VENDOR_DAEWOO		0x1070 /*Daewoo Telecom Ltd*/
#define VENDOR_MITAC		0x1071 /*Mitac*/
#define VENDOR_GIT		0x1072 /*GIT Co Ltd*/
#define VENDOR_YAMAHA		0x1073 /*Yamaha Corporation*/
#define VENDOR_NEXGEN		0x1074 /*NexGen Microsystems*/
#define VENDOR_ADVANCED2	0x1075 /*Advanced Integrations Research*/
#define VENDOR_CHAINTECH	0x1076 /*Chaintech Computer Co. Ltd*/
#define VENDOR_QLOGIC		0x1077 /*QLogic Corp.*/
#define VENDOR_CYRIX		0x1078 /*Cyrix Corporation*/
#define VENDOR_I_BUS		0x1079 /*I-Bus*/
#define VENDOR_NETWORTH		0x107a /*NetWorth*/
#define VENDOR_GATEWAY		0x107b /*Gateway 2000*/
#define VENDOR_LG_ELECTRONICS	0x107c /*LG Electronics [Lucky Goldstar Co. Ltd]*/
#define VENDOR_LEADTEK		0x107d /*LeadTek Research Inc.*/
#define VENDOR_INTERPHASE	0x107e /*Interphase Corporation*/
#define VENDOR_DATA		0x107f /*Data Technology Corporation*/
#define VENDOR_CONTAQ		0x1080 /*Contaq Microsystems*/
#define VENDOR_SUPERMAC		0x1081 /*Supermac Technology*/
#define VENDOR_EFA		0x1082 /*EFA Corporation of America*/
#define VENDOR_FOREX		0x1083 /*Forex Computer Corporation*/
#define VENDOR_PARADOR		0x1084 /*Parador*/
#define VENDOR_TULIP		0x1085 /*Tulip Computers Int.B.V.*/
#define VENDOR_J_BOND		0x1086 /*J. Bond Computer Systems*/
#define VENDOR_CACHE		0x1087 /*Cache Computer*/
#define VENDOR_MICROCOMPUTER	0x1088 /*Microcomputer Systems (M) Son*/
#define VENDOR_DATA2		0x1089 /*Data General Corporation*/
#define VENDOR_SBS		0x108a /*SBS Technologies*/
#define VENDOR_OAKLEIGH		0x108c /*Oakleigh Systems Inc.*/
#define VENDOR_OLICOM		0x108d /*Olicom*/
#define VENDOR_SUN		0x108e /*Sun Microsystems Computer Corp.*/
#define VENDOR_SYSTEMSOFT	0x108f /*Systemsoft*/
#define VENDOR_ENCORE		0x1090 /*Encore Computer Corporation*/
#define VENDOR_INTERGRAPH	0x1091 /*Intergraph Corporation*/
#define VENDOR_DIAMOND		0x1092 /*Diamond Multimedia Systems*/
#define VENDOR_NATIONAL2	0x1093 /*National Instruments*/
#define VENDOR_FIRST		0x1094 /*First International Computers [FIC]*/
#define VENDOR_SILICON3		0x1095 /*Silicon Image, Inc. (formerly CMD Technology Inc)*/
#define VENDOR_ALACRON		0x1096 /*Alacron*/
#define VENDOR_APPIAN		0x1097 /*Appian Technology*/
#define VENDOR_QUANTUM		0x1098 /*Quantum Designs (H.K.) Ltd*/
#define VENDOR_SAMSUNG		0x1099 /*Samsung Electronics Co., Ltd*/
#define VENDOR_PACKARD		0x109a /*Packard Bell*/
#define VENDOR_GEMLIGHT		0x109b /*Gemlight Computer Ltd.*/
#define VENDOR_MEGACHIPS	0x109c /*Megachips Corporation*/
#define VENDOR_ZIDA		0x109d /*Zida Technologies Ltd.*/
#define VENDOR_BROOKTREE	0x109e /*Brooktree Corporation*/
#define VENDOR_TRIGEM		0x109f /*Trigem Computer Inc.*/
#define VENDOR_MEIDENSHA	0x10a0 /*Meidensha Corporation*/
#define VENDOR_JUKO		0x10a1 /*Juko Electronics Ind. Co. Ltd*/
#define VENDOR_QUANTUM2		0x10a2 /*Quantum Corporation*/
#define VENDOR_EVEREX		0x10a3 /*Everex Systems Inc*/
#define VENDOR_GLOBE		0x10a4 /*Globe Manufacturing Sales*/
#define VENDOR_SMART		0x10a5 /*Smart Link Ltd.*/
#define VENDOR_INFORMTECH	0x10a6 /*Informtech Industrial Ltd.*/
#define VENDOR_BENCHMARQ	0x10a7 /*Benchmarq Microelectronics*/
#define VENDOR_SIERRA		0x10a8 /*Sierra Semiconductor*/
#define VENDOR_SILICON4		0x10a9 /*Silicon Graphics, Inc.*/
#define VENDOR_ACC		0x10aa /*ACC Microelectronics*/
#define VENDOR_DIGICOM		0x10ab /*Digicom*/
#define VENDOR_HONEYWELL	0x10ac /*Honeywell IAC*/
#define VENDOR_SYMPHONY		0x10ad /*Symphony Labs*/
#define VENDOR_CORNERSTONE	0x10ae /*Cornerstone Technology*/
#define VENDOR_MICRO		0x10af /*Micro Computer Systems Inc*/
#define VENDOR_CARDEXPERT	0x10b0 /*CardExpert Technology*/
#define VENDOR_CABLETRON	0x10b1 /*Cabletron Systems Inc*/
#define VENDOR_RAYTHEON		0x10b2 /*Raytheon Company*/
#define VENDOR_DATABOOK		0x10b3 /*Databook Inc*/
#define VENDOR_STB		0x10b4 /*STB Systems Inc*/
#define VENDOR_PLX		0x10b5 /*PLX Technology, Inc.*/
#define VENDOR_MADGE		0x10b6 /*Madge Networks*/
#define VENDOR_3COM		0x10b7 /*3Com Corporation*/
#define VENDOR_STANDARD		0x10b8 /*Standard Microsystems Corp [SMC]*/
#define VENDOR_ALI		0x10b9 /*ALi Corporation*/
#define VENDOR_MITSUBISHI2	0x10ba /*Mitsubishi Electric Corp.*/
#define VENDOR_DAPHA		0x10bb /*Dapha Electronics Corporation*/
#define VENDOR_ADVANCED3	0x10bc /*Advanced Logic Research*/
#define VENDOR_SURECOM		0x10bd /*Surecom Technology*/
#define VENDOR_TSENG2		0x10be /*Tseng Labs International Co.*/
#define VENDOR_MOST		0x10bf /*Most Inc*/
#define VENDOR_BOCA		0x10c0 /*Boca Research Inc.*/
#define VENDOR_ICM		0x10c1 /*ICM Co., Ltd.*/
#define VENDOR_AUSPEX		0x10c2 /*Auspex Systems Inc.*/
#define VENDOR_SAMSUNG2		0x10c3 /*Samsung Semiconductors, Inc.*/
#define VENDOR_AWARD		0x10c4 /*Award Software International Inc.*/
#define VENDOR_XEROX		0x10c5 /*Xerox Corporation*/
#define VENDOR_RAMBUS		0x10c6 /*Rambus Inc.*/
#define VENDOR_MEDIA		0x10c7 /*Media Vision*/
#define VENDOR_NEOMAGIC		0x10c8 /*Neomagic Corporation*/
#define VENDOR_DATAEXPERT	0x10c9 /*Dataexpert Corporation*/
#define VENDOR_FUJITSU		0x10ca /*Fujitsu Microelectr., Inc.*/
#define VENDOR_OMRON		0x10cb /*Omron Corporation*/
#define VENDOR_MAI		0x10cc /*Mai Logic Incorporated*/
#define VENDOR_ADVANCED4	0x10cd /*Advanced System Products, Inc*/
#define VENDOR_RADIUS		0x10ce /*Radius*/
#define VENDOR_FUJITSU2		0x10cf /*Fujitsu Limited.*/
#define VENDOR_FUTUREPLUS	0x10d1 /*FuturePlus Systems Corp.*/
#define VENDOR_MOLEX		0x10d2 /*Molex Incorporated*/
#define VENDOR_JABIL		0x10d3 /*Jabil Circuit Inc*/
#define VENDOR_HUALON		0x10d4 /*Hualon Microelectronics*/
#define VENDOR_AUTOLOGIC	0x10d5 /*Autologic Inc.*/
#define VENDOR_CETIA		0x10d6 /*Cetia*/
#define VENDOR_BCM		0x10d7 /*BCM Advanced Research*/
#define VENDOR_ADVANCED5	0x10d8 /*Advanced Peripherals Labs*/
#define VENDOR_MACRONIX		0x10d9 /*Macronix, Inc. [MXIC]*/
#define VENDOR_COMPAQ4		0x10da /*Compaq IPG-Austin*/
#define VENDOR_ROHM		0x10db /*Rohm LSI Systems, Inc.*/
#define VENDOR_CERN_ECP_EDU	0x10dc /*CERN/ECP/EDU*/
#define VENDOR_EVANS		0x10dd /*Evans & Sutherland*/
#define VENDOR_NVIDIA		0x10de /*nVidia Corporation*/
#define VENDOR_EMULEX		0x10df /*Emulex Corporation*/
#define VENDOR_INTEGRATED	0x10e0 /*Integrated Micro Solutions Inc.*/
#define VENDOR_TEKRAM		0x10e1 /*Tekram Technology Co.,Ltd.*/
#define VENDOR_APTIX		0x10e2 /*Aptix Corporation*/
#define VENDOR_TUNDRA		0x10e3 /*Tundra Semiconductor Corp.*/
#define VENDOR_TANDEM		0x10e4 /*Tandem Computers*/
#define VENDOR_MICRO2		0x10e5 /*Micro Industries Corporation*/
#define VENDOR_GAINBERY		0x10e6 /*Gainbery Computer Products Inc.*/
#define VENDOR_VADEM		0x10e7 /*Vadem*/
#define VENDOR_APPLIED		0x10e8 /*Applied Micro Circuits Corp.*/
#define VENDOR_ALPS		0x10e9 /*Alps Electric Co., Ltd.*/
#define VENDOR_INTERGRAPHICS	0x10ea /*Intergraphics Systems*/
#define VENDOR_ARTISTS		0x10eb /*Artists Graphics*/
#define VENDOR_REALTEK		0x10ec /*Realtek Semiconductor Co., Ltd.*/
#define VENDOR_ASCII2		0x10ed /*Ascii Corporation*/
#define VENDOR_XILINX		0x10ee /*Xilinx Corporation*/
#define VENDOR_RACORE		0x10ef /*Racore Computer Products, Inc.*/
#define VENDOR_PERITEK		0x10f0 /*Peritek Corporation*/
#define VENDOR_TYAN		0x10f1 /*Tyan Computer*/
#define VENDOR_ACHME		0x10f2 /*Achme Computer, Inc.*/
#define VENDOR_ALARIS		0x10f3 /*Alaris, Inc.*/
#define VENDOR_S_MOS		0x10f4 /*S-MOS Systems, Inc.*/
#define VENDOR_NKK		0x10f5 /*NKK Corporation*/
#define VENDOR_CREATIVE		0x10f6 /*Creative Electronic Systems SA*/
#define VENDOR_MATSUSHITA	0x10f7 /*Matsushita Electric Industrial Co., Ltd.*/
#define VENDOR_ALTOS		0x10f8 /*Altos India Ltd*/
#define VENDOR_PC_DIRECT	0x10f9 /*PC Direct*/
#define VENDOR_TRUEVISION	0x10fa /*Truevision*/
#define VENDOR_THESYS		0x10fb /*Thesys Gesellschaft für Mikroelektronik mbH*/
#define VENDOR_I_O		0x10fc /*I-O Data Device, Inc.*/
#define VENDOR_SOYO		0x10fd /*Soyo Computer, Inc*/
#define VENDOR_FAST		0x10fe /*Fast Multimedia AG*/
#define VENDOR_NCUBE		0x10ff /*NCube*/
#define VENDOR_JAZZ		0x1100 /*Jazz Multimedia*/
#define VENDOR_INITIO		0x1101 /*Initio Corporation*/
#define VENDOR_CREATIVE2	0x1102 /*Creative Labs*/
#define VENDOR_TRIONES		0x1103 /*Triones Technologies, Inc.*/
#define VENDOR_RASTEROPS	0x1104 /*RasterOps Corp.*/
#define VENDOR_SIGMA		0x1105 /*Sigma Designs, Inc.*/
#define VENDOR_VIA2		0x1106 /*VIA Technologies, Inc.*/
#define VENDOR_STRATUS		0x1107 /*Stratus Computers*/
#define VENDOR_PROTEON		0x1108 /*Proteon, Inc.*/
#define VENDOR_COGENT		0x1109 /*Cogent Data Technologies, Inc.*/
#define VENDOR_SIEMENS2		0x110a /*Siemens Nixdorf AG*/
#define VENDOR_CHROMATIC	0x110b /*Chromatic Research Inc.*/
#define VENDOR_MINI_MAX		0x110c /*Mini-Max Technology, Inc.*/
#define VENDOR_ZNYX		0x110d /*Znyx Advanced Systems*/
#define VENDOR_CPU		0x110e /*CPU Technology*/
#define VENDOR_ROSS		0x110f /*Ross Technology*/
#define VENDOR_POWERHOUSE	0x1110 /*Powerhouse Systems*/
#define VENDOR_SANTA		0x1111 /*Santa Cruz Operation*/
#define VENDOR_OSICOM		0x1112 /*Osicom Technologies Inc*/
#define VENDOR_ACCTON		0x1113 /*Accton Technology Corporation*/
#define VENDOR_ATMEL		0x1114 /*Atmel Corporation*/
#define VENDOR_3D_LABS		0x1115 /*3D Labs*/
#define VENDOR_DATA3		0x1116 /*Data Translation*/
#define VENDOR_DATACUBE		0x1117 /*Datacube, Inc*/
#define VENDOR_BERG		0x1118 /*Berg Electronics*/
#define VENDOR_ICP		0x1119 /*ICP Vortex Computersysteme GmbH*/
#define VENDOR_EFFICIENT	0x111a /*Efficient Networks, Inc*/
#define VENDOR_TELEDYNE		0x111b /*Teledyne Electronic Systems*/
#define VENDOR_TRICORD		0x111c /*Tricord Systems Inc.*/
#define VENDOR_INTEGRATED2	0x111d /*Integrated Device Technology, Inc.*/
#define VENDOR_ELDEC		0x111e /*Eldec*/
#define VENDOR_PRECISION	0x111f /*Precision Digital Images*/
#define VENDOR_EMC		0x1120 /*EMC Corporation*/
#define VENDOR_ZILOG		0x1121 /*Zilog*/
#define VENDOR_MULTI_TECH	0x1122 /*Multi-tech Systems, Inc.*/
#define VENDOR_EXCELLENT	0x1123 /*Excellent Design, Inc.*/
#define VENDOR_LEUTRON		0x1124 /*Leutron Vision AG*/
#define VENDOR_EUROCORE		0x1125 /*Eurocore*/
#define VENDOR_VIGRA		0x1126 /*Vigra*/
#define VENDOR_FORE		0x1127 /*FORE Systems Inc*/
#define VENDOR_FIRMWORKS	0x1129 /*Firmworks*/
#define VENDOR_HERMES		0x112a /*Hermes Electronics Company, Ltd.*/
#define VENDOR_LINOTYPE		0x112b /*Linotype - Hell AG*/
#define VENDOR_ZENITH2		0x112c /*Zenith Data Systems*/
#define VENDOR_RAVICAD		0x112d /*Ravicad*/
#define VENDOR_INFOMEDIA	0x112e /*Infomedia Microelectronics Inc.*/
#define VENDOR_IMAGING		0x112f /*Imaging Technology Inc*/
#define VENDOR_COMPUTERVISION	0x1130 /*Computervision*/
#define VENDOR_PHILIPS		0x1131 /*Philips Semiconductors*/
#define VENDOR_MITEL		0x1132 /*Mitel Corp.*/
#define VENDOR_EICON		0x1133 /*Eicon Networks Corporation*/
#define VENDOR_MERCURY		0x1134 /*Mercury Computer Systems*/
#define VENDOR_FUJI		0x1135 /*Fuji Xerox Co Ltd*/
#define VENDOR_MOMENTUM		0x1136 /*Momentum Data Systems*/
#define VENDOR_CISCO		0x1137 /*Cisco Systems Inc*/
#define VENDOR_ZIATECH		0x1138 /*Ziatech Corporation*/
#define VENDOR_DYNAMIC		0x1139 /*Dynamic Pictures, Inc*/
#define VENDOR_FWB		0x113a /*FWB Inc*/
#define VENDOR_NETWORK		0x113b /*Network Computing Devices*/
#define VENDOR_CYCLONE		0x113c /*Cyclone Microsystems, Inc.*/
#define VENDOR_LEADING		0x113d /*Leading Edge Products Inc*/
#define VENDOR_SANYO		0x113e /*Sanyo Electric Co - Computer Engineering Dept*/
#define VENDOR_EQUINOX		0x113f /*Equinox Systems, Inc.*/
#define VENDOR_INTERVOICE	0x1140 /*Intervoice Inc*/
#define VENDOR_CREST		0x1141 /*Crest Microsystem Inc*/
#define VENDOR_ALLIANCE		0x1142 /*Alliance Semiconductor Corporation*/
#define VENDOR_NETPOWER		0x1143 /*NetPower, Inc*/
#define VENDOR_CINCINNATI	0x1144 /*Cincinnati Milacron*/
#define VENDOR_WORKBIT		0x1145 /*Workbit Corporation*/
#define VENDOR_FORCE		0x1146 /*Force Computers*/
#define VENDOR_INTERFACE	0x1147 /*Interface Corp*/
#define VENDOR_SYSKONNECT	0x1148 /*SysKonnect*/
#define VENDOR_WIN		0x1149 /*Win System Corporation*/
#define VENDOR_VMIC		0x114a /*VMIC*/
#define VENDOR_CANOPUS		0x114b /*Canopus Co., Ltd*/
#define VENDOR_ANNABOOKS	0x114c /*Annabooks*/
#define VENDOR_IC_CORPORATION	0x114d /*IC Corporation*/
#define VENDOR_NIKON		0x114e /*Nikon Systems Inc*/
#define VENDOR_DIGI		0x114f /*Digi International*/
#define VENDOR_THINKING		0x1150 /*Thinking Machines Corp*/
#define VENDOR_JAE		0x1151 /*JAE Electronics Inc.*/
#define VENDOR_MEGATEK		0x1152 /*Megatek*/
#define VENDOR_LAND		0x1153 /*Land Win Electronic Corp*/
#define VENDOR_MELCO		0x1154 /*Melco Inc*/
#define VENDOR_PINE		0x1155 /*Pine Technology Ltd*/
#define VENDOR_PERISCOPE	0x1156 /*Periscope Engineering*/
#define VENDOR_AVSYS		0x1157 /*Avsys Corporation*/
#define VENDOR_VOARX		0x1158 /*Voarx R & D Inc*/
#define VENDOR_MUTECH		0x1159 /*Mutech Corp*/
#define VENDOR_HARLEQUIN	0x115a /*Harlequin Ltd*/
#define VENDOR_PARALLAX		0x115b /*Parallax Graphics*/
#define VENDOR_PHOTRON		0x115c /*Photron Ltd.*/
#define VENDOR_XIRCOM		0x115d /*Xircom*/
#define VENDOR_PEER		0x115e /*Peer Protocols Inc*/
#define VENDOR_MAXTOR		0x115f /*Maxtor Corporation*/
#define VENDOR_MEGASOFT		0x1160 /*Megasoft Inc*/
#define VENDOR_PFU		0x1161 /*PFU Limited*/
#define VENDOR_OA_LABORATORY	0x1162 /*OA Laboratory Co Ltd*/
#define VENDOR_RENDITION	0x1163 /*Rendition*/
#define VENDOR_ADVANCED6	0x1164 /*Advanced Peripherals Technologies*/
#define VENDOR_IMAGRAPH		0x1165 /*Imagraph Corporation*/
#define VENDOR_SERVERWORKS	0x1166 /*ServerWorks*/
#define VENDOR_MUTOH		0x1167 /*Mutoh Industries Inc*/
#define VENDOR_THINE		0x1168 /*Thine Electronics Inc*/
#define VENDOR_CENTRE		0x1169 /*Centre for Development of Advanced Computing*/
#define VENDOR_POLARIS		0x116a /*Polaris Communications*/
#define VENDOR_CONNECTWARE	0x116b /*Connectware Inc*/
#define VENDOR_INTELLIGENT	0x116c /*Intelligent Resources Integrated Systems*/
#define VENDOR_MARTIN_MARIETTA	0x116d /*Martin-Marietta*/
#define VENDOR_ELECTRONICS2	0x116e /*Electronics for Imaging*/
#define VENDOR_WORKSTATION	0x116f /*Workstation Technology*/
#define VENDOR_INVENTEC		0x1170 /*Inventec Corporation*/
#define VENDOR_LOUGHBOROUGH	0x1171 /*Loughborough Sound Images Plc*/
#define VENDOR_ALTERA		0x1172 /*Altera Corporation*/
#define VENDOR_ADOBE		0x1173 /*Adobe Systems, Inc*/
#define VENDOR_BRIDGEPORT	0x1174 /*Bridgeport Machines*/
#define VENDOR_MITRON		0x1175 /*Mitron Computer Inc.*/
#define VENDOR_SBE		0x1176 /*SBE Incorporated*/
#define VENDOR_SILICON5		0x1177 /*Silicon Engineering*/
#define VENDOR_ALFA		0x1178 /*Alfa, Inc.*/
#define VENDOR_TOSHIBA2		0x1179 /*Toshiba America Info Systems*/
#define VENDOR_A_TREND		0x117a /*A-Trend Technology*/
#define VENDOR_L_G		0x117b /*L G Electronics, Inc.*/
#define VENDOR_ATTO		0x117c /*Atto Technology*/
#define VENDOR_BECTON		0x117d /*Becton & Dickinson*/
#define VENDOR_T_R		0x117e /*T/R Systems*/
#define VENDOR_INTEGRATED3	0x117f /*Integrated Circuit Systems*/
#define VENDOR_RICOH		0x1180 /*Ricoh Co Ltd*/
#define VENDOR_TELMATICS	0x1181 /*Telmatics International*/
#define VENDOR_FUJIKURA		0x1183 /*Fujikura Ltd*/
#define VENDOR_FORKS		0x1184 /*Forks Inc*/
#define VENDOR_DATAWORLD	0x1185 /*Dataworld International Ltd*/
#define VENDOR_D_LINK		0x1186 /*D-Link System Inc*/
#define VENDOR_ADVANCED7	0x1187 /*Advanced Technology Laboratories, Inc.*/
#define VENDOR_SHIMA		0x1188 /*Shima Seiki Manufacturing Ltd.*/
#define VENDOR_MATSUSHITA2	0x1189 /*Matsushita Electronics Co Ltd*/
#define VENDOR_HILEVEL		0x118a /*Hilevel Technology*/
#define VENDOR_HYPERTEC		0x118b /*Hypertec Pty Limited*/
#define VENDOR_COROLLARY	0x118c /*Corollary, Inc*/
#define VENDOR_BITFLOW		0x118d /*BitFlow Inc*/
#define VENDOR_HERMSTEDT	0x118e /*Hermstedt GmbH*/
#define VENDOR_GREEN		0x118f /*Green Logic*/
#define VENDOR_TRIPACE		0x1190 /*Tripace*/
#define VENDOR_ARTOP		0x1191 /*Artop Electronic Corp*/
#define VENDOR_DENSAN		0x1192 /*Densan Company Ltd*/
#define VENDOR_ZEITNET		0x1193 /*Zeitnet Inc.*/
#define VENDOR_TOUCAN		0x1194 /*Toucan Technology*/
#define VENDOR_RATOC		0x1195 /*Ratoc System Inc*/
#define VENDOR_HYTEC		0x1196 /*Hytec Electronics Ltd*/
#define VENDOR_GAGE		0x1197 /*Gage Applied Sciences, Inc.*/
#define VENDOR_LAMBDA		0x1198 /*Lambda Systems Inc*/
#define VENDOR_ATTACHMATE	0x1199 /*Attachmate Corporation*/
#define VENDOR_MIND		0x119a /*Mind Share, Inc.*/
#define VENDOR_OMEGA		0x119b /*Omega Micro Inc.*/
#define VENDOR_INFORMATION	0x119c /*Information Technology Inst.*/
#define VENDOR_BUG		0x119d /*Bug, Inc. Sapporo Japan*/
#define VENDOR_FUJITSU3		0x119e /*Fujitsu Microelectronics Ltd.*/
#define VENDOR_BULL		0x119f /*Bull HN Information Systems*/
#define VENDOR_CONVEX		0x11a0 /*Convex Computer Corporation*/
#define VENDOR_HAMAMATSU	0x11a1 /*Hamamatsu Photonics K.K.*/
#define VENDOR_SIERRA2		0x11a2 /*Sierra Research and Technology*/
#define VENDOR_DEURETZBACHER	0x11a3 /*Deuretzbacher GmbH & Co. Eng. KG*/
#define VENDOR_BARCO		0x11a4 /*Barco Graphics NV*/
#define VENDOR_MICROUNITY	0x11a5 /*Microunity Systems Eng. Inc*/
#define VENDOR_PURE		0x11a6 /*Pure Data Ltd.*/
#define VENDOR_POWER		0x11a7 /*Power Computing Corp.*/
#define VENDOR_SYSTECH		0x11a8 /*Systech Corp.*/
#define VENDOR_INNOSYS		0x11a9 /*InnoSys Inc.*/
#define VENDOR_ACTEL		0x11aa /*Actel*/
#define VENDOR_MARVELL		0x11ab /*Marvell Technology Group Ltd.*/
#define VENDOR_CANON		0x11ac /*Canon Information Systems Research Aust.*/
#define VENDOR_LITE_ON		0x11ad /*Lite-On Communications Inc*/
#define VENDOR_AZTECH		0x11ae /*Aztech System Ltd*/
#define VENDOR_AVID		0x11af /*Avid Technology Inc.*/
#define VENDOR_V3_SEMICONDUCTOR	0x11b0 /*V3 Semiconductor Inc.*/
#define VENDOR_APRICOT		0x11b1 /*Apricot Computers*/
#define VENDOR_EASTMAN		0x11b2 /*Eastman Kodak*/
#define VENDOR_BARR		0x11b3 /*Barr Systems Inc.*/
#define VENDOR_LEITCH		0x11b4 /*Leitch Technology International*/
#define VENDOR_RADSTONE		0x11b5 /*Radstone Technology Plc*/
#define VENDOR_UNITED2		0x11b6 /*United Video Corp*/
#define VENDOR_MOTOROLA2	0x11b7 /*Motorola*/
#define VENDOR_XPOINT		0x11b8 /*XPoint Technologies, Inc*/
#define VENDOR_PATHLIGHT	0x11b9 /*Pathlight Technology Inc.*/
#define VENDOR_VIDEOTRON	0x11ba /*Videotron Corp*/
#define VENDOR_PYRAMID		0x11bb /*Pyramid Technology*/
#define VENDOR_NETWORK2		0x11bc /*Network Peripherals Inc*/
#define VENDOR_PINNACLE		0x11bd /*Pinnacle Systems Inc.*/
#define VENDOR_INTERNATIONAL	0x11be /*International Microcircuits Inc*/
#define VENDOR_ASTRODESIGN	0x11bf /*Astrodesign, Inc.*/
#define VENDOR_HEWLETT		0x11c0 /*Hewlett Packard*/
#define VENDOR_AGERE		0x11c1 /*Agere Systems (former Lucent Microelectronics)*/
#define VENDOR_SAND		0x11c2 /*Sand Microelectronics*/
#define VENDOR_NEC2		0x11c3 /*NEC Corporation*/
#define VENDOR_DOCUMENT		0x11c4 /*Document Technologies, Inc*/
#define VENDOR_SHIVA		0x11c5 /*Shiva Corporation*/
#define VENDOR_DAINIPPON	0x11c6 /*Dainippon Screen Mfg. Co. Ltd*/
#define VENDOR_D_C_M		0x11c7 /*D.C.M. Data Systems*/
#define VENDOR_DOLPHIN		0x11c8 /*Dolphin Interconnect Solutions AS*/
#define VENDOR_MAGMA		0x11c9 /*Magma*/
#define VENDOR_LSI4		0x11ca /*LSI Systems, Inc*/
#define VENDOR_SPECIALIX	0x11cb /*Specialix Research Ltd.*/
#define VENDOR_MICHELS		0x11cc /*Michels & Kleberhoff Computer GmbH*/
#define VENDOR_HAL		0x11cd /*HAL Computer Systems, Inc.*/
#define VENDOR_NETACCESS	0x11ce /*Netaccess*/
#define VENDOR_PIONEER		0x11cf /*Pioneer Electronic Corporation*/
#define VENDOR_LOCKHEED2	0x11d0 /*Lockheed Martin Federal Systems-Manassas*/
#define VENDOR_AURAVISION	0x11d1 /*Auravision*/
#define VENDOR_INTERCOM		0x11d2 /*Intercom Inc.*/
#define VENDOR_TRANCELL		0x11d3 /*Trancell Systems Inc*/
#define VENDOR_ANALOG		0x11d4 /*Analog Devices*/
#define VENDOR_IKON		0x11d5 /*Ikon Corporation*/
#define VENDOR_TEKELEC		0x11d6 /*Tekelec Telecom*/
#define VENDOR_TRENTON		0x11d7 /*Trenton Technology, Inc.*/
#define VENDOR_IMAGE		0x11d8 /*Image Technologies Development*/
#define VENDOR_TEC		0x11d9 /*TEC Corporation*/
#define VENDOR_NOVELL		0x11da /*Novell*/
#define VENDOR_SEGA		0x11db /*Sega Enterprises Ltd*/
#define VENDOR_QUESTRA		0x11dc /*Questra Corporation*/
#define VENDOR_CROSFIELD	0x11dd /*Crosfield Electronics Limited*/
#define VENDOR_ZORAN		0x11de /*Zoran Corporation*/
#define VENDOR_NEW		0x11df /*New Wave PDG*/
#define VENDOR_CRAY		0x11e0 /*Cray Communications A/S*/
#define VENDOR_GEC		0x11e1 /*GEC Plessey Semi Inc.*/
#define VENDOR_SAMSUNG3		0x11e2 /*Samsung Information Systems America*/
#define VENDOR_QUICKLOGIC	0x11e3 /*Quicklogic Corporation*/
#define VENDOR_SECOND		0x11e4 /*Second Wave Inc*/
#define VENDOR_IIX		0x11e5 /*IIX Consulting*/
#define VENDOR_MITSUI_ZOSEN	0x11e6 /*Mitsui-Zosen System Research*/
#define VENDOR_TOSHIBA3		0x11e7 /*Toshiba America, Elec. Company*/
#define VENDOR_DIGITAL2		0x11e8 /*Digital Processing Systems Inc.*/
#define VENDOR_HIGHWATER	0x11e9 /*Highwater Designs Ltd.*/
#define VENDOR_ELSAG		0x11ea /*Elsag Bailey*/
#define VENDOR_FORMATION	0x11eb /*Formation Inc.*/
#define VENDOR_CORECO		0x11ec /*Coreco Inc*/
#define VENDOR_MEDIAMATICS	0x11ed /*Mediamatics*/
#define VENDOR_DOME		0x11ee /*Dome Imaging Systems Inc*/
#define VENDOR_NICOLET		0x11ef /*Nicolet Technologies B.V.*/
#define VENDOR_COMPU_SHACK	0x11f0 /*Compu-Shack*/
#define VENDOR_SYMBIOS		0x11f1 /*Symbios Logic Inc*/
#define VENDOR_PICTURE		0x11f2 /*Picture Tel Japan K.K.*/
#define VENDOR_KEITHLEY		0x11f3 /*Keithley Metrabyte*/
#define VENDOR_KINETIC		0x11f4 /*Kinetic Systems Corporation*/
#define VENDOR_COMPUTING	0x11f5 /*Computing Devices International*/
#define VENDOR_COMPEX		0x11f6 /*Compex*/
#define VENDOR_SCIENTIFIC	0x11f7 /*Scientific Atlanta*/
#define VENDOR_PMC_SIERRA	0x11f8 /*PMC-Sierra Inc.*/
#define VENDOR_I_CUBE		0x11f9 /*I-Cube Inc*/
#define VENDOR_KASAN		0x11fa /*Kasan Electronics Company, Ltd.*/
#define VENDOR_DATEL		0x11fb /*Datel Inc*/
#define VENDOR_SILICON6		0x11fc /*Silicon Magic*/
#define VENDOR_HIGH		0x11fd /*High Street Consultants*/
#define VENDOR_COMTROL		0x11fe /*Comtrol Corporation*/
#define VENDOR_SCION		0x11ff /*Scion Corporation*/
#define VENDOR_CSS		0x1200 /*CSS Corporation*/
#define VENDOR_VISTA		0x1201 /*Vista Controls Corp*/
#define VENDOR_NETWORK3		0x1202 /*Network General Corp.*/
#define VENDOR_BAYER		0x1203 /*Bayer Corporation, Agfa Division*/
#define VENDOR_LATTICE		0x1204 /*Lattice Semiconductor Corporation*/
#define VENDOR_ARRAY		0x1205 /*Array Corporation*/
#define VENDOR_AMDAHL		0x1206 /*Amdahl Corporation*/
#define VENDOR_PARSYTEC		0x1208 /*Parsytec GmbH*/
#define VENDOR_SCI		0x1209 /*SCI Systems Inc*/
#define VENDOR_SYNAPTEL		0x120a /*Synaptel*/
#define VENDOR_ADAPTIVE		0x120b /*Adaptive Solutions*/
#define VENDOR_TECHNICAL	0x120c /*Technical Corp.*/
#define VENDOR_COMPRESSION	0x120d /*Compression Labs, Inc.*/
#define VENDOR_CYCLADES		0x120e /*Cyclades Corporation*/
#define VENDOR_ESSENTIAL	0x120f /*Essential Communications*/
#define VENDOR_HYPERPARALLEL	0x1210 /*Hyperparallel Technologies*/
#define VENDOR_BRAINTECH	0x1211 /*Braintech Inc*/
#define VENDOR_KINGSTON		0x1212 /*Kingston Technology Corp.*/
#define VENDOR_APPLIED2		0x1213 /*Applied Intelligent Systems, Inc.*/
#define VENDOR_PERFORMANCE	0x1214 /*Performance Technologies, Inc.*/
#define VENDOR_INTERWARE	0x1215 /*Interware Co., Ltd*/
#define VENDOR_PURUP		0x1216 /*Purup Prepress A/S*/
#define VENDOR_O2_MICRO		0x1217 /*O2 Micro, Inc.*/
#define VENDOR_HYBRICON		0x1218 /*Hybricon Corp.*/
#define VENDOR_FIRST2		0x1219 /*First Virtual Corporation*/
#define VENDOR_3DFX		0x121a /*3Dfx Interactive, Inc.*/
#define VENDOR_ADVANCED8	0x121b /*Advanced Telecommunications Modules*/
#define VENDOR_NIPPON		0x121c /*Nippon Texaco., Ltd*/
#define VENDOR_LIPPERT		0x121d /*Lippert Automationstechnik GmbH*/
#define VENDOR_CSPI		0x121e /*CSPI*/
#define VENDOR_ARCUS		0x121f /*Arcus Technology, Inc.*/
#define VENDOR_ARIEL		0x1220 /*Ariel Corporation*/
#define VENDOR_CONTEC		0x1221 /*Contec Co., Ltd*/
#define VENDOR_ANCOR		0x1222 /*Ancor Communications, Inc.*/
#define VENDOR_ARTESYN		0x1223 /*Artesyn Communication Products*/
#define VENDOR_INTERACTIVE	0x1224 /*Interactive Images*/
#define VENDOR_POWER2		0x1225 /*Power I/O, Inc.*/
#define VENDOR_TECH_SOURCE	0x1227 /*Tech-Source*/
#define VENDOR_NORSK		0x1228 /*Norsk Elektro Optikk A/S*/
#define VENDOR_DATA4		0x1229 /*Data Kinesis Inc.*/
#define VENDOR_INTEGRATED4	0x122a /*Integrated Telecom*/
#define VENDOR_LG_INDUSTRIAL	0x122b /*LG Industrial Systems Co., Ltd*/
#define VENDOR_SICAN		0x122c /*Sican GmbH*/
#define VENDOR_AZTECH2		0x122d /*Aztech System Ltd*/
#define VENDOR_XYRATEX		0x122e /*Xyratex*/
#define VENDOR_ANDREW		0x122f /*Andrew Corporation*/
#define VENDOR_FISHCAMP		0x1230 /*Fishcamp Engineering*/
#define VENDOR_WOODWARD		0x1231 /*Woodward McCoach, Inc.*/
#define VENDOR_GPT		0x1232 /*GPT Limited*/
#define VENDOR_BUS_TECH		0x1233 /*Bus-Tech, Inc.*/
#define VENDOR_TECHNICAL2	0x1234 /*Technical Corp.*/
#define VENDOR_RISQ		0x1235 /*Risq Modular Systems, Inc.*/
#define VENDOR_SIGMA2		0x1236 /*Sigma Designs Corporation*/
#define VENDOR_ALTA		0x1237 /*Alta Technology Corporation*/
#define VENDOR_ADTRAN		0x1238 /*Adtran*/
#define VENDOR_3DO		0x1239 /*3DO Company*/
#define VENDOR_VISICOM		0x123a /*Visicom Laboratories, Inc.*/
#define VENDOR_SEEQ		0x123b /*Seeq Technology, Inc.*/
#define VENDOR_CENTURY		0x123c /*Century Systems, Inc.*/
#define VENDOR_ENGINEERING	0x123d /*Engineering Design Team, Inc.*/
#define VENDOR_SIMUTECH		0x123e /*Simutech, Inc.*/
#define VENDOR_C_CUBE		0x123f /*C-Cube Microsystems*/
#define VENDOR_MARATHON		0x1240 /*Marathon Technologies Corp.*/
#define VENDOR_DSC		0x1241 /*DSC Communications*/
#define VENDOR_JNI		0x1242 /*JNI Corporation*/
#define VENDOR_DELPHAX		0x1243 /*Delphax*/
#define VENDOR_AVM		0x1244 /*AVM Audiovisuelles MKTG & Computer System GmbH*/
#define VENDOR_A_P_D		0x1245 /*A.P.D., S.A.*/
#define VENDOR_DIPIX		0x1246 /*Dipix Technologies, Inc.*/
#define VENDOR_XYLON		0x1247 /*Xylon Research, Inc.*/
#define VENDOR_CENTRAL		0x1248 /*Central Data Corporation*/
#define VENDOR_SAMSUNG4		0x1249 /*Samsung Electronics Co., Ltd.*/
#define VENDOR_AEG		0x124a /*AEG Electrocom GmbH*/
#define VENDOR_SBS_GREENSPRING	0x124b /*SBS/Greenspring Modular I/O*/
#define VENDOR_SOLITRON		0x124c /*Solitron Technologies, Inc.*/
#define VENDOR_STALLION		0x124d /*Stallion Technologies, Inc.*/
#define VENDOR_CYLINK		0x124e /*Cylink*/
#define VENDOR_INFOTREND	0x124f /*Infotrend Technology, Inc.*/
#define VENDOR_HITACHI4		0x1250 /*Hitachi Microcomputer System Ltd*/
#define VENDOR_VLSI2		0x1251 /*VLSI Solutions Oy*/
#define VENDOR_GUZIK		0x1253 /*Guzik Technical Enterprises*/
#define VENDOR_LINEAR		0x1254 /*Linear Systems Ltd.*/
#define VENDOR_OPTIBASE		0x1255 /*Optibase Ltd*/
#define VENDOR_PERCEPTIVE	0x1256 /*Perceptive Solutions, Inc.*/
#define VENDOR_VERTEX		0x1257 /*Vertex Networks, Inc.*/
#define VENDOR_GILBARCO		0x1258 /*Gilbarco, Inc.*/
#define VENDOR_ALLIED		0x1259 /*Allied Telesyn International*/
#define VENDOR_ABB		0x125a /*ABB Power Systems*/
#define VENDOR_ASIX		0x125b /*Asix Electronics Corporation*/
#define VENDOR_AURORA		0x125c /*Aurora Technologies, Inc.*/
#define VENDOR_ESS		0x125d /*ESS Technology*/
#define VENDOR_SPECIALVIDEO	0x125e /*Specialvideo Engineering SRL*/
#define VENDOR_CONCURRENT	0x125f /*Concurrent Technologies, Inc.*/
#define VENDOR_INTERSIL		0x1260 /*Intersil Corporation*/
#define VENDOR_MATSUSHITA_KOTOBUKI	0x1261 /*Matsushita-Kotobuki Electronics Industries, Ltd.*/
#define VENDOR_ES_COMPUTER	0x1262 /*ES Computer Company, Ltd.*/
#define VENDOR_SONIC		0x1263 /*Sonic Solutions*/
#define VENDOR_AVAL		0x1264 /*Aval Nagasaki Corporation*/
#define VENDOR_CASIO		0x1265 /*Casio Computer Co., Ltd.*/
#define VENDOR_MICRODYNE	0x1266 /*Microdyne Corporation*/
#define VENDOR_S_A		0x1267 /*S. A. Telecommunications*/
#define VENDOR_TEKTRONIX	0x1268 /*Tektronix*/
#define VENDOR_THOMSON_CSF_TTM	0x1269 /*Thomson-CSF/TTM*/
#define VENDOR_LEXMARK		0x126a /*Lexmark International, Inc.*/
#define VENDOR_ADAX		0x126b /*Adax, Inc.*/
#define VENDOR_NORTHERN		0x126c /*Northern Telecom*/
#define VENDOR_SPLASH		0x126d /*Splash Technology, Inc.*/
#define VENDOR_SUMITOMO		0x126e /*Sumitomo Metal Industries, Ltd.*/
#define VENDOR_SILICON7		0x126f /*Silicon Motion, Inc.*/
#define VENDOR_OLYMPUS		0x1270 /*Olympus Optical Co., Ltd.*/
#define VENDOR_GW_INSTRUMENTS	0x1271 /*GW Instruments*/
#define VENDOR_TELEMATICS	0x1272 /*Telematics International*/
#define VENDOR_HUGHES		0x1273 /*Hughes Network Systems*/
#define VENDOR_ENSONIQ		0x1274 /*Ensoniq*/
#define VENDOR_NETWORK4		0x1275 /*Network Appliance Corporation*/
#define VENDOR_SWITCHED		0x1276 /*Switched Network Technologies, Inc.*/
#define VENDOR_COMSTREAM	0x1277 /*Comstream*/
#define VENDOR_TRANSTECH	0x1278 /*Transtech Parallel Systems Ltd.*/
#define VENDOR_TRANSMETA	0x1279 /*Transmeta Corporation*/
#define VENDOR_ROCKWELL		0x127a /*Rockwell International*/
#define VENDOR_PIXERA		0x127b /*Pixera Corporation*/
#define VENDOR_CROSSPOINT	0x127c /*Crosspoint Solutions, Inc.*/
#define VENDOR_VELA		0x127d /*Vela Research*/
#define VENDOR_WINNOV		0x127e /*Winnov, L.P.*/
#define VENDOR_FUJIFILM		0x127f /*Fujifilm*/
#define VENDOR_PHOTOSCRIPT	0x1280 /*Photoscript Group Ltd.*/
#define VENDOR_YOKOGAWA		0x1281 /*Yokogawa Electric Corporation*/
#define VENDOR_DAVICOM2		0x1282 /*Davicom Semiconductor, Inc.*/
#define VENDOR_INTEGRATED5	0x1283 /*Integrated Technology Express, Inc.*/
#define VENDOR_SAHARA		0x1284 /*Sahara Networks, Inc.*/
#define VENDOR_PLATFORM		0x1285 /*Platform Technologies, Inc.*/
#define VENDOR_MAZET		0x1286 /*Mazet GmbH*/
#define VENDOR_M_PACT		0x1287 /*M-Pact, Inc.*/
#define VENDOR_TIMESTEP		0x1288 /*Timestep Corporation*/
#define VENDOR_AVC		0x1289 /*AVC Technology, Inc.*/
#define VENDOR_ASANTE		0x128a /*Asante Technologies, Inc.*/
#define VENDOR_TRANSWITCH	0x128b /*Transwitch Corporation*/
#define VENDOR_RETIX		0x128c /*Retix Corporation*/
#define VENDOR_G2_NETWORKS	0x128d /*G2 Networks, Inc.*/
#define VENDOR_HOONTECH		0x128e /*Hoontech Corporation/Samho Multi Tech Ltd.*/
#define VENDOR_TATENO		0x128f /*Tateno Dennou, Inc.*/
#define VENDOR_SORD		0x1290 /*Sord Computer Corporation*/
#define VENDOR_NCS		0x1291 /*NCS Computer Italia*/
#define VENDOR_TRITECH		0x1292 /*Tritech Microelectronics Inc*/
#define VENDOR_MEDIA2		0x1293 /*Media Reality Technology*/
#define VENDOR_RHETOREX		0x1294 /*Rhetorex, Inc.*/
#define VENDOR_IMAGENATION	0x1295 /*Imagenation Corporation*/
#define VENDOR_KOFAX		0x1296 /*Kofax Image Products*/
#define VENDOR_HOLCO		0x1297 /*Holco Enterprise Co, Ltd/Shuttle Computer*/
#define VENDOR_SPELLCASTER	0x1298 /*Spellcaster Telecommunications Inc.*/
#define VENDOR_KNOWLEDGE	0x1299 /*Knowledge Technology Lab.*/
#define VENDOR_VMETRO		0x129a /*VMetro, inc.*/
#define VENDOR_IMAGE2		0x129b /*Image Access*/
#define VENDOR_JAYCOR		0x129c /*Jaycor*/
#define VENDOR_COMPCORE		0x129d /*Compcore Multimedia, Inc.*/
#define VENDOR_VICTOR		0x129e /*Victor Company of Japan, Ltd.*/
#define VENDOR_OEC		0x129f /*OEC Medical Systems, Inc.*/
#define VENDOR_ALLEN_BRADLEY	0x12a0 /*Allen-Bradley Company*/
#define VENDOR_SIMPACT		0x12a1 /*Simpact Associates, Inc.*/
#define VENDOR_NEWGEN		0x12a2 /*Newgen Systems Corporation*/
#define VENDOR_LUCENT		0x12a3 /*Lucent Technologies*/
#define VENDOR_NTT		0x12a4 /*NTT Electronics Technology Company*/
#define VENDOR_VISION		0x12a5 /*Vision Dynamics Ltd.*/
#define VENDOR_SCALABLE		0x12a6 /*Scalable Networks, Inc.*/
#define VENDOR_AMO		0x12a7 /*AMO GmbH*/
#define VENDOR_NEWS		0x12a8 /*News Datacom*/
#define VENDOR_XIOTECH		0x12a9 /*Xiotech Corporation*/
#define VENDOR_SDL		0x12aa /*SDL Communications, Inc.*/
#define VENDOR_YUAN		0x12ab /*Yuan Yuan Enterprise Co., Ltd.*/
#define VENDOR_MEASUREX		0x12ac /*Measurex Corporation*/
#define VENDOR_MULTIDATA	0x12ad /*Multidata GmbH*/
#define VENDOR_ALTEON		0x12ae /*Alteon Networks Inc.*/
#define VENDOR_TDK		0x12af /*TDK USA Corp*/
#define VENDOR_JORGE		0x12b0 /*Jorge Scientific Corp*/
#define VENDOR_GAMMALINK	0x12b1 /*GammaLink*/
#define VENDOR_GENERAL		0x12b2 /*General Signal Networks*/
#define VENDOR_INTER_FACE	0x12b3 /*Inter-Face Co Ltd*/
#define VENDOR_FUTURETEL	0x12b4 /*FutureTel Inc*/
#define VENDOR_GRANITE		0x12b5 /*Granite Systems Inc.*/
#define VENDOR_NATURAL		0x12b6 /*Natural Microsystems*/
#define VENDOR_COGNEX		0x12b7 /*Cognex Modular Vision Systems Div. - Acumen Inc.*/
#define VENDOR_KORG		0x12b8 /*Korg*/
#define VENDOR_3COM2		0x12b9 /*3Com Corp, Modem Division (formerly US Robotics)*/
#define VENDOR_BITTWARE		0x12ba /*BittWare, Inc.*/
#define VENDOR_NIPPON2		0x12bb /*Nippon Unisoft Corporation*/
#define VENDOR_ARRAY2		0x12bc /*Array Microsystems*/
#define VENDOR_COMPUTERM	0x12bd /*Computerm Corp.*/
#define VENDOR_ANCHOR		0x12be /*Anchor Chips Inc.*/
#define VENDOR_FUJIFILM2	0x12bf /*Fujifilm Microdevices*/
#define VENDOR_INFIMED		0x12c0 /*Infimed*/
#define VENDOR_GMM		0x12c1 /*GMM Research Corp*/
#define VENDOR_MENTEC		0x12c2 /*Mentec Limited*/
#define VENDOR_HOLTEK		0x12c3 /*Holtek Microelectronics Inc*/
#define VENDOR_CONNECT		0x12c4 /*Connect Tech Inc*/
#define VENDOR_PICTURE2		0x12c5 /*Picture Elements Incorporated*/
#define VENDOR_MITANI		0x12c6 /*Mitani Corporation*/
#define VENDOR_DIALOGIC		0x12c7 /*Dialogic Corp*/
#define VENDOR_G_FORCE		0x12c8 /*G Force Co, Ltd*/
#define VENDOR_GIGI		0x12c9 /*Gigi Operations*/
#define VENDOR_INTEGRATED6	0x12ca /*Integrated Computing Engines*/
#define VENDOR_ANTEX		0x12cb /*Antex Electronics Corporation*/
#define VENDOR_PLUTO		0x12cc /*Pluto Technologies International*/
#define VENDOR_AIMS		0x12cd /*Aims Lab*/
#define VENDOR_NETSPEED		0x12ce /*Netspeed Inc.*/
#define VENDOR_PROPHET		0x12cf /*Prophet Systems, Inc.*/
#define VENDOR_GDE		0x12d0 /*GDE Systems, Inc.*/
#define VENDOR_PSITECH		0x12d1 /*PSITech*/
#define VENDOR_NVIDIA2		0x12d2 /*NVidia / SGS Thomson (Joint Venture)*/
#define VENDOR_VINGMED		0x12d3 /*Vingmed Sound A/S*/
#define VENDOR_ULTICOM		0x12d4 /*Ulticom (Formerly DGM&S)*/
#define VENDOR_EQUATOR		0x12d5 /*Equator Technologies Inc*/
#define VENDOR_ANALOGIC		0x12d6 /*Analogic Corp*/
#define VENDOR_BIOTRONIC	0x12d7 /*Biotronic SRL*/
#define VENDOR_PERICOM		0x12d8 /*Pericom Semiconductor*/
#define VENDOR_ACULAB		0x12d9 /*Aculab PLC*/
#define VENDOR_TRUE		0x12da /*True Time Inc.*/
#define VENDOR_ANNAPOLIS	0x12db /*Annapolis Micro Systems, Inc*/
#define VENDOR_SYMICRON		0x12dc /*Symicron Computer Communication Ltd.*/
#define VENDOR_MANAGEMENT	0x12dd /*Management Graphics*/
#define VENDOR_RAINBOW		0x12de /*Rainbow Technologies*/
#define VENDOR_SBS2		0x12df /*SBS Technologies Inc*/
#define VENDOR_CHASE		0x12e0 /*Chase Research*/
#define VENDOR_NINTENDO		0x12e1 /*Nintendo Co, Ltd*/
#define VENDOR_DATUM		0x12e2 /*Datum Inc. Bancomm-Timing Division*/
#define VENDOR_IMATION		0x12e3 /*Imation Corp - Medical Imaging Systems*/
#define VENDOR_BROOKTROUT	0x12e4 /*Brooktrout Technology Inc*/
#define VENDOR_APEX		0x12e5 /*Apex Semiconductor Inc*/
#define VENDOR_CIREL		0x12e6 /*Cirel Systems*/
#define VENDOR_SUNSGROUP	0x12e7 /*Sunsgroup Corporation*/
#define VENDOR_CRISC		0x12e8 /*Crisc Corp*/
#define VENDOR_GE_SPACENET	0x12e9 /*GE Spacenet*/
#define VENDOR_ZUKEN		0x12ea /*Zuken*/
#define VENDOR_AUREAL		0x12eb /*Aureal Semiconductor*/
#define VENDOR_3A_INTERNATIONAL	0x12ec /*3A International, Inc.*/
#define VENDOR_OPTIVISION	0x12ed /*Optivision Inc.*/
#define VENDOR_ORANGE		0x12ee /*Orange Micro*/
#define VENDOR_VIENNA		0x12ef /*Vienna Systems*/
#define VENDOR_PENTEK		0x12f0 /*Pentek*/
#define VENDOR_SORENSON		0x12f1 /*Sorenson Vision Inc*/
#define VENDOR_GAMMAGRAPHX2	0x12f2 /*Gammagraphx, Inc.*/
#define VENDOR_RADSTONE2	0x12f3 /*Radstone Technology*/
#define VENDOR_MEGATEL		0x12f4 /*Megatel*/
#define VENDOR_FORKS2		0x12f5 /*Forks*/
#define VENDOR_DAWSON		0x12f6 /*Dawson France*/
#define VENDOR_COGNEX2		0x12f7 /*Cognex*/
#define VENDOR_ELECTRONIC	0x12f8 /*Electronic Design GmbH*/
#define VENDOR_FOUR		0x12f9 /*Four Fold Ltd*/
#define VENDOR_SPECTRUM		0x12fb /*Spectrum Signal Processing*/
#define VENDOR_CAPITAL		0x12fc /*Capital Equipment Corp*/
#define VENDOR_I2S		0x12fd /*I2S*/
#define VENDOR_ESD		0x12fe /*ESD Electronic System Design GmbH*/
#define VENDOR_LEXICON		0x12ff /*Lexicon*/
#define VENDOR_HARMAN		0x1300 /*Harman International Industries Inc*/
#define VENDOR_COMPUTER		0x1302 /*Computer Sciences Corp*/
#define VENDOR_INNOVATIVE	0x1303 /*Innovative Integration*/
#define VENDOR_JUNIPER		0x1304 /*Juniper Networks*/
#define VENDOR_NETPHONE		0x1305 /*Netphone, Inc*/
#define VENDOR_DUET		0x1306 /*Duet Technologies*/
#define VENDOR_MEASUREMENT	0x1307 /*Measurement Computing*/
#define VENDOR_JATO		0x1308 /*Jato Technologies Inc.*/
#define VENDOR_AB_SEMICONDUCTOR	0x1309 /*AB Semiconductor Ltd*/
#define VENDOR_MITSUBISHI3	0x130a /*Mitsubishi Electric Microcomputer*/
#define VENDOR_COLORGRAPHIC	0x130b /*Colorgraphic Communications Corp*/
#define VENDOR_AMBEX		0x130c /*Ambex Technologies, Inc*/
#define VENDOR_ACCELERIX	0x130d /*Accelerix Inc*/
#define VENDOR_YAMATAKE_HONEYWELL	0x130e /*Yamatake-Honeywell Co. Ltd*/
#define VENDOR_ADVANET		0x130f /*Advanet Inc*/
#define VENDOR_GESPAC		0x1310 /*Gespac*/
#define VENDOR_VIDEOSERVER	0x1311 /*Videoserver, Inc*/
#define VENDOR_ACUITY		0x1312 /*Acuity Imaging, Inc*/
#define VENDOR_YASKAWA		0x1313 /*Yaskawa Electric Co.*/
#define VENDOR_TERADYNE		0x1316 /*Teradyne Inc*/
#define VENDOR_LINKSYS		0x1317 /*Linksys*/
#define VENDOR_PACKET		0x1318 /*Packet Engines Inc.*/
#define VENDOR_FORTEMEDIA	0x1319 /*Fortemedia, Inc*/
#define VENDOR_FINISAR		0x131a /*Finisar Corp.*/
#define VENDOR_NIPPON3		0x131c /*Nippon Electro-Sensory Devices Corp*/
#define VENDOR_SYSMIC		0x131d /*Sysmic, Inc.*/
#define VENDOR_XINEX		0x131e /*Xinex Networks Inc*/
#define VENDOR_SIIG		0x131f /*Siig Inc*/
#define VENDOR_CRYPTO		0x1320 /*Crypto AG*/
#define VENDOR_ARCOBEL		0x1321 /*Arcobel Graphics BV*/
#define VENDOR_MTT		0x1322 /*MTT Co., Ltd*/
#define VENDOR_DOME2		0x1323 /*Dome Inc*/
#define VENDOR_SPHERE		0x1324 /*Sphere Communications*/
#define VENDOR_SALIX		0x1325 /*Salix Technologies, Inc*/
#define VENDOR_SEACHANGE	0x1326 /*Seachange international*/
#define VENDOR_VOSS		0x1327 /*Voss scientific*/
#define VENDOR_QUADRANT		0x1328 /*quadrant international*/
#define VENDOR_PRODUCTIVITY	0x1329 /*Productivity Enhancement*/
#define VENDOR_MICROCOM		0x132a /*Microcom Inc.*/
#define VENDOR_BROADBAND	0x132b /*Broadband Technologies*/
#define VENDOR_MICREL		0x132c /*Micrel Inc*/
#define VENDOR_INTEGRATED7	0x132d /*Integrated Silicon Solution, Inc.*/
#define VENDOR_MMC		0x1330 /*MMC Networks*/
#define VENDOR_RADISYS		0x1331 /*Radisys Corp.*/
#define VENDOR_MICRO3		0x1332 /*Micro Memory*/
#define VENDOR_REDCREEK		0x1334 /*Redcreek Communications, Inc*/
#define VENDOR_VIDEOMAIL	0x1335 /*Videomail, Inc*/
#define VENDOR_THIRD		0x1337 /*Third Planet Publishing*/
#define VENDOR_BT_ELECTRONICS	0x1338 /*BT Electronics*/
#define VENDOR_VTEL		0x133a /*Vtel Corp*/
#define VENDOR_SOFTCOM		0x133b /*Softcom Microsystems*/
#define VENDOR_HOLONTECH	0x133c /*Holontech Corp*/
#define VENDOR_SS_TECHNOLOGIES	0x133d /*SS Technologies*/
#define VENDOR_VIRTUAL		0x133e /*Virtual Computer Corp*/
#define VENDOR_SCM		0x133f /*SCM Microsystems*/
#define VENDOR_ATALLA		0x1340 /*Atalla Corp*/
#define VENDOR_KYOTO		0x1341 /*Kyoto Microcomputer Co*/
#define VENDOR_PROMAX		0x1342 /*Promax Systems Inc*/
#define VENDOR_PHYLON		0x1343 /*Phylon Communications Inc*/
#define VENDOR_CRUCIAL		0x1344 /*Crucial Technology*/
#define VENDOR_ARESCOM		0x1345 /*Arescom Inc*/
#define VENDOR_ODETICS		0x1347 /*Odetics*/
#define VENDOR_SUMITOMO2	0x1349 /*Sumitomo Electric Industries, Ltd.*/
#define VENDOR_DTC		0x134a /*DTC Technology Corp.*/
#define VENDOR_ARK		0x134b /*ARK Research Corp.*/
#define VENDOR_CHORI		0x134c /*Chori Joho System Co. Ltd*/
#define VENDOR_PCTEL		0x134d /*PCTel Inc*/
#define VENDOR_CSTI		0x134e /*CSTI*/
#define VENDOR_ALGO		0x134f /*Algo System Co Ltd*/
#define VENDOR_SYSTEC		0x1350 /*Systec Co. Ltd*/
#define VENDOR_SONIX		0x1351 /*Sonix Inc*/
#define VENDOR_THALES		0x1353 /*Thales Idatys*/
#define VENDOR_DWAVE		0x1354 /*Dwave System Inc*/
#define VENDOR_KRATOS		0x1355 /*Kratos Analytical Ltd*/
#define VENDOR_THE		0x1356 /*The Logical Co*/
#define VENDOR_PRISA		0x1359 /*Prisa Networks*/
#define VENDOR_BRAIN		0x135a /*Brain Boxes*/
#define VENDOR_GIGANET		0x135b /*Giganet Inc*/
#define VENDOR_QUATECH		0x135c /*Quatech Inc*/
#define VENDOR_ABB2		0x135d /*ABB Network Partner AB*/
#define VENDOR_SEALEVEL		0x135e /*Sealevel Systems Inc*/
#define VENDOR_I_DATA		0x135f /*I-Data International A-S*/
#define VENDOR_MEINBERG		0x1360 /*Meinberg Funkuhren*/
#define VENDOR_SOLITON		0x1361 /*Soliton Systems K.K.*/
#define VENDOR_FUJIFACOM	0x1362 /*Fujifacom Corporation*/
#define VENDOR_PHOENIX2		0x1363 /*Phoenix Technology Ltd*/
#define VENDOR_ATM		0x1364 /*ATM Communications Inc*/
#define VENDOR_HYPERCOPE	0x1365 /*Hypercope GmbH*/
#define VENDOR_TEIJIN		0x1366 /*Teijin Seiki Co. Ltd*/
#define VENDOR_HITACHI5		0x1367 /*Hitachi Zosen Corporation*/
#define VENDOR_SKYWARE		0x1368 /*Skyware Corporation*/
#define VENDOR_DIGIGRAM		0x1369 /*Digigram*/
#define VENDOR_HIGH2		0x136a /*High Soft Tech*/
#define VENDOR_KAWASAKI		0x136b /*Kawasaki Steel Corporation*/
#define VENDOR_ADTEK		0x136c /*Adtek System Science Co Ltd*/
#define VENDOR_GIGALABS		0x136d /*Gigalabs Inc*/
#define VENDOR_APPLIED3		0x136f /*Applied Magic Inc*/
#define VENDOR_ATL		0x1370 /*ATL Products*/
#define VENDOR_CNET		0x1371 /*CNet Technology Inc*/
#define VENDOR_SILICON8		0x1373 /*Silicon Vision Inc*/
#define VENDOR_SILICOM		0x1374 /*Silicom Ltd*/
#define VENDOR_ARGOSYSTEMS	0x1375 /*Argosystems Inc*/
#define VENDOR_LMC		0x1376 /*LMC*/
#define VENDOR_ELECTRONIC2	0x1377 /*Electronic Equipment Production & Distribution GmbH*/
#define VENDOR_TELEMANN		0x1378 /*Telemann Co. Ltd*/
#define VENDOR_ASAHI		0x1379 /*Asahi Kasei Microsystems Co Ltd*/
#define VENDOR_MARK		0x137a /*Mark of the Unicorn Inc*/
#define VENDOR_PPT		0x137b /*PPT Vision*/
#define VENDOR_IWATSU		0x137c /*Iwatsu Electric Co Ltd*/
#define VENDOR_DYNACHIP		0x137d /*Dynachip Corporation*/
#define VENDOR_PATRIOT		0x137e /*Patriot Scientific Corporation*/
#define VENDOR_JAPAN		0x137f /*Japan Satellite Systems Inc*/
#define VENDOR_SANRITZ		0x1380 /*Sanritz Automation Co Ltd*/
#define VENDOR_BRAINS		0x1381 /*Brains Co. Ltd*/
#define VENDOR_MARIAN		0x1382 /*Marian - Electronic & Software*/
#define VENDOR_CONTROLNET	0x1383 /*Controlnet Inc*/
#define VENDOR_REALITY		0x1384 /*Reality Simulation Systems Inc*/
#define VENDOR_NETGEAR		0x1385 /*Netgear*/
#define VENDOR_VIDEO2		0x1386 /*Video Domain Technologies*/
#define VENDOR_SYSTRAN		0x1387 /*Systran Corp*/
#define VENDOR_HITACHI6		0x1388 /*Hitachi Information Technology Co Ltd*/
#define VENDOR_APPLICOM		0x1389 /*Applicom International*/
#define VENDOR_FUSION		0x138a /*Fusion Micromedia Corp*/
#define VENDOR_TOKIMEC		0x138b /*Tokimec Inc*/
#define VENDOR_SILICON9		0x138c /*Silicon Reality*/
#define VENDOR_FUTURE2		0x138d /*Future Techno Designs pte Ltd*/
#define VENDOR_BASLER		0x138e /*Basler GmbH*/
#define VENDOR_PATAPSCO		0x138f /*Patapsco Designs Inc*/
#define VENDOR_CONCEPT		0x1390 /*Concept Development Inc*/
#define VENDOR_DEVELOPMENT	0x1391 /*Development Concepts Inc*/
#define VENDOR_MEDIALIGHT	0x1392 /*Medialight Inc*/
#define VENDOR_MOXA		0x1393 /*Moxa Technologies Co Ltd*/
#define VENDOR_LEVEL		0x1394 /*Level One Communications*/
#define VENDOR_AMBICOM		0x1395 /*Ambicom Inc*/
#define VENDOR_CIPHER		0x1396 /*Cipher Systems Inc*/
#define VENDOR_COLOGNE		0x1397 /*Cologne Chip Designs GmbH*/
#define VENDOR_CLARION		0x1398 /*Clarion co. Ltd*/
#define VENDOR_RIOS		0x1399 /*Rios systems Co Ltd*/
#define VENDOR_ALACRITECH	0x139a /*Alacritech Inc*/
#define VENDOR_MEDIASONIC	0x139b /*Mediasonic Multimedia Systems Ltd*/
#define VENDOR_QUANTUM3		0x139c /*Quantum 3d Inc*/
#define VENDOR_EPL		0x139d /*EPL limited*/
#define VENDOR_MEDIA4		0x139e /*Media4*/
#define VENDOR_AETHRA		0x139f /*Aethra s.r.l.*/
#define VENDOR_CRYSTAL		0x13a0 /*Crystal Group Inc*/
#define VENDOR_KAWASAKI2	0x13a1 /*Kawasaki Heavy Industries Ltd*/
#define VENDOR_OSITECH		0x13a2 /*Ositech Communications Inc*/
#define VENDOR_HIFN		0x13a3 /*Hifn Inc.*/
#define VENDOR_RASCOM		0x13a4 /*Rascom Inc*/
#define VENDOR_AUDIO		0x13a5 /*Audio Digital Imaging Inc*/
#define VENDOR_VIDEONICS	0x13a6 /*Videonics Inc*/
#define VENDOR_TELES		0x13a7 /*Teles AG*/
#define VENDOR_EXAR		0x13a8 /*Exar Corp.*/
#define VENDOR_SIEMENS3		0x13a9 /*Siemens Medical Systems, Ultrasound Group*/
#define VENDOR_BROADBAND2	0x13aa /*Broadband Networks Inc*/
#define VENDOR_ARCOM		0x13ab /*Arcom Control Systems Ltd*/
#define VENDOR_MOTION		0x13ac /*Motion Media Technology Ltd*/
#define VENDOR_NEXUS		0x13ad /*Nexus Inc*/
#define VENDOR_ALD		0x13ae /*ALD Technology Ltd*/
#define VENDOR_T_SQWARE		0x13af /*T.Sqware*/
#define VENDOR_MAXSPEED		0x13b0 /*Maxspeed Corp*/
#define VENDOR_TAMURA		0x13b1 /*Tamura corporation*/
#define VENDOR_TECHNO		0x13b2 /*Techno Chips Co. Ltd*/
#define VENDOR_LANART		0x13b3 /*Lanart Corporation*/
#define VENDOR_WELLBEAN		0x13b4 /*Wellbean Co Inc*/
#define VENDOR_ARM		0x13b5 /*ARM*/
#define VENDOR_DLOG		0x13b6 /*Dlog GmbH*/
#define VENDOR_LOGIC		0x13b7 /*Logic Devices Inc*/
#define VENDOR_NOKIA		0x13b8 /*Nokia Telecommunications oy*/
#define VENDOR_ELECOM		0x13b9 /*Elecom Co Ltd*/
#define VENDOR_OXFORD		0x13ba /*Oxford Instruments*/
#define VENDOR_SANYO2		0x13bb /*Sanyo Technosound Co Ltd*/
#define VENDOR_BITRAN		0x13bc /*Bitran Corporation*/
#define VENDOR_SHARP		0x13bd /*Sharp corporation*/
#define VENDOR_MIROKU		0x13be /*Miroku Jyoho Service Co. Ltd*/
#define VENDOR_SHAREWAVE	0x13bf /*Sharewave Inc*/
#define VENDOR_MICROGATE	0x13c0 /*Microgate Corporation*/
#define VENDOR_3WARE		0x13c1 /*3ware Inc*/
#define VENDOR_TECHNOTREND	0x13c2 /*Technotrend Systemtechnik GmbH*/
#define VENDOR_JANZ		0x13c3 /*Janz Computer AG*/
#define VENDOR_PHASE		0x13c4 /*Phase Metrics*/
#define VENDOR_ALPHI		0x13c5 /*Alphi Technology Corp*/
#define VENDOR_CONDOR		0x13c6 /*Condor Engineering Inc*/
#define VENDOR_BLUE		0x13c7 /*Blue Chip Technology Ltd*/
#define VENDOR_APPTECH		0x13c8 /*Apptech Inc*/
#define VENDOR_EATON		0x13c9 /*Eaton Corporation*/
#define VENDOR_IOMEGA		0x13ca /*Iomega Corporation*/
#define VENDOR_YANO		0x13cb /*Yano Electric Co Ltd*/
#define VENDOR_METHEUS		0x13cc /*Metheus Corporation*/
#define VENDOR_COMPATIBLE	0x13cd /*Compatible Systems Corporation*/
#define VENDOR_COCOM		0x13ce /*Cocom A/S*/
#define VENDOR_STUDIO		0x13cf /*Studio Audio & Video Ltd*/
#define VENDOR_TECHSAN		0x13d0 /*Techsan Electronics Co Ltd*/
#define VENDOR_ABOCOM		0x13d1 /*Abocom Systems Inc*/
#define VENDOR_SHARK		0x13d2 /*Shark Multimedia Inc*/
#define VENDOR_IMC		0x13d3 /*IMC Networks*/
#define VENDOR_GRAPHICS		0x13d4 /*Graphics Microsystems Inc*/
#define VENDOR_MEDIA3		0x13d5 /*Media 100 Inc*/
#define VENDOR_K_I		0x13d6 /*K.I. Technology Co Ltd*/
#define VENDOR_TOSHIBA4		0x13d7 /*Toshiba Engineering Corporation*/
#define VENDOR_PHOBOS		0x13d8 /*Phobos corporation*/
#define VENDOR_APEX2		0x13d9 /*Apex PC Solutions Inc*/
#define VENDOR_INTRESOURCE	0x13da /*Intresource Systems pte Ltd*/
#define VENDOR_JANICH		0x13db /*Janich & Klass Computertechnik GmbH*/
#define VENDOR_NETBOOST		0x13dc /*Netboost Corporation*/
#define VENDOR_MULTIMEDIA	0x13dd /*Multimedia Bundle Inc*/
#define VENDOR_ABB3		0x13de /*ABB Robotics Products AB*/
#define VENDOR_E_TECH		0x13df /*E-Tech Inc*/
#define VENDOR_GVC		0x13e0 /*GVC Corporation*/
#define VENDOR_SILICOM2		0x13e1 /*Silicom Multimedia Systems Inc*/
#define VENDOR_DYNAMICS		0x13e2 /*Dynamics Research Corporation*/
#define VENDOR_NEST		0x13e3 /*Nest Inc*/
#define VENDOR_CALCULEX		0x13e4 /*Calculex Inc*/
#define VENDOR_TELESOFT		0x13e5 /*Telesoft Design Ltd*/
#define VENDOR_ARGOSY		0x13e6 /*Argosy research Inc*/
#define VENDOR_NAC		0x13e7 /*NAC Incorporated*/
#define VENDOR_CHIP		0x13e8 /*Chip Express Corporation*/
#define VENDOR_INTRASERVER	0x13e9 /*Intraserver Technology Inc*/
#define VENDOR_DALLAS		0x13ea /*Dallas Semiconductor*/
#define VENDOR_HAUPPAUGE2	0x13eb /*Hauppauge Computer Works Inc*/
#define VENDOR_ZYDACRON		0x13ec /*Zydacron Inc*/
#define VENDOR_RAYTHEION	0x13ed /*Raytheion E-Systems*/
#define VENDOR_HAYES		0x13ee /*Hayes Microcomputer Products Inc*/
#define VENDOR_COPPERCOM	0x13ef /*Coppercom Inc*/
#define VENDOR_SUNDANCE		0x13f0 /*Sundance Technology Inc*/
#define VENDOR_OCE		0x13f1 /*Oce' - Technologies B.V.*/
#define VENDOR_FORD		0x13f2 /*Ford Microelectronics Inc*/
#define VENDOR_MCDATA		0x13f3 /*Mcdata Corporation*/
#define VENDOR_TROIKA		0x13f4 /*Troika Networks, Inc.*/
#define VENDOR_KANSAI		0x13f5 /*Kansai Electric Co. Ltd*/
#define VENDOR_C_MEDIA		0x13f6 /*C-Media Electronics Inc*/
#define VENDOR_WILDFIRE		0x13f7 /*Wildfire Communications*/
#define VENDOR_AD_LIB		0x13f8 /*Ad Lib Multimedia Inc*/
#define VENDOR_NTT2		0x13f9 /*NTT Advanced Technology Corp.*/
#define VENDOR_PENTLAND		0x13fa /*Pentland Systems Ltd*/
#define VENDOR_AYDIN		0x13fb /*Aydin Corp*/
#define VENDOR_COMPUTER2	0x13fc /*Computer Peripherals International*/
#define VENDOR_MICRO4		0x13fd /*Micro Science Inc*/
#define VENDOR_ADVANTECH	0x13fe /*Advantech Co. Ltd*/
#define VENDOR_SILICON10	0x13ff /*Silicon Spice Inc*/
#define VENDOR_ARTX		0x1400 /*Artx Inc*/
#define VENDOR_CR_SYSTEMS	0x1401 /*CR-Systems A/S*/
#define VENDOR_MEILHAUS		0x1402 /*Meilhaus Electronic GmbH*/
#define VENDOR_ASCOR		0x1403 /*Ascor Inc*/
#define VENDOR_FUNDAMENTAL	0x1404 /*Fundamental Software Inc*/
#define VENDOR_EXCALIBUR	0x1405 /*Excalibur Systems Inc*/
#define VENDOR_OCE2		0x1406 /*Oce' Printing Systems GmbH*/
#define VENDOR_LAVA		0x1407 /*Lava Computer mfg Inc*/
#define VENDOR_ALOKA		0x1408 /*Aloka Co. Ltd*/
#define VENDOR_TIMEDIA		0x1409 /*Timedia Technology Co Ltd*/
#define VENDOR_DSP		0x140a /*DSP Research Inc*/
#define VENDOR_RAMIX		0x140b /*Ramix Inc*/
#define VENDOR_ELMIC		0x140c /*Elmic Systems Inc*/
#define VENDOR_MATSUSHITA3	0x140d /*Matsushita Electric Works Ltd*/
#define VENDOR_GOEPEL		0x140e /*Goepel Electronic GmbH*/
#define VENDOR_SALIENT		0x140f /*Salient Systems Corp*/
#define VENDOR_MIDAS		0x1410 /*Midas lab Inc*/
#define VENDOR_IKOS		0x1411 /*Ikos Systems Inc*/
#define VENDOR_VIA3		0x1412 /*VIA Technologies Inc.*/
#define VENDOR_ADDONICS		0x1413 /*Addonics*/
#define VENDOR_MICROSOFT	0x1414 /*Microsoft Corporation*/
#define VENDOR_OXFORD2		0x1415 /*Oxford Semiconductor Ltd*/
#define VENDOR_MULTIWAVE	0x1416 /*Multiwave Innovation pte Ltd*/
#define VENDOR_CONVERGENET	0x1417 /*Convergenet Technologies Inc*/
#define VENDOR_KYUSHU		0x1418 /*Kyushu electronics systems Inc*/
#define VENDOR_EXCEL		0x1419 /*Excel Switching Corp*/
#define VENDOR_APACHE		0x141a /*Apache Micro Peripherals Inc*/
#define VENDOR_ZOOM		0x141b /*Zoom Telephonics Inc*/
#define VENDOR_DIGITAN		0x141d /*Digitan Systems Inc*/
#define VENDOR_FANUC		0x141e /*Fanuc Ltd*/
#define VENDOR_VISIONTECH	0x141f /*Visiontech Ltd*/
#define VENDOR_PSION		0x1420 /*Psion Dacom plc*/
#define VENDOR_ADS		0x1421 /*Ads Technologies Inc*/
#define VENDOR_YGREC		0x1422 /*Ygrec Systems Co Ltd*/
#define VENDOR_CUSTOM		0x1423 /*Custom Technology Corp.*/
#define VENDOR_VIDEOSERVER2	0x1424 /*Videoserver Connections*/
#define VENDOR_CHELSIO		0x1425 /*Chelsio Communications Inc*/
#define VENDOR_STORAGE		0x1426 /*Storage Technology Corp.*/
#define VENDOR_BETTER		0x1427 /*Better On-Line Solutions*/
#define VENDOR_EDEC		0x1428 /*Edec Co Ltd*/
#define VENDOR_UNEX		0x1429 /*Unex Technology Corp.*/
#define VENDOR_KINGMAX		0x142a /*Kingmax Technology Inc*/
#define VENDOR_RADIOLAN		0x142b /*Radiolan*/
#define VENDOR_MINTON		0x142c /*Minton Optic Industry Co Ltd*/
#define VENDOR_PIX		0x142d /*Pix stream Inc*/
#define VENDOR_VITEC		0x142e /*Vitec Multimedia*/
#define VENDOR_RADICOM		0x142f /*Radicom Research Inc*/
#define VENDOR_ITT		0x1430 /*ITT Aerospace/Communications Division*/
#define VENDOR_GILAT		0x1431 /*Gilat Satellite Networks*/
#define VENDOR_EDIMAX		0x1432 /*Edimax Computer Co.*/
#define VENDOR_ELTEC		0x1433 /*Eltec Elektronik GmbH*/
#define VENDOR_REAL		0x1435 /*Real Time Devices US Inc.*/
#define VENDOR_CIS		0x1436 /*CIS Technology Inc*/
#define VENDOR_NISSIN		0x1437 /*Nissin Inc Co*/
#define VENDOR_ATMEL_DREAM	0x1438 /*Atmel-dream*/
#define VENDOR_OUTSOURCE	0x1439 /*Outsource Engineering & Mfg. Inc*/
#define VENDOR_STARGATE		0x143a /*Stargate Solutions Inc*/
#define VENDOR_CANON2		0x143b /*Canon Research Center, America*/
#define VENDOR_AMLOGIC		0x143c /*Amlogic Inc*/
#define VENDOR_TAMARACK		0x143d /*Tamarack Microelectronics Inc*/
#define VENDOR_JONES		0x143e /*Jones Futurex Inc*/
#define VENDOR_LIGHTWELL	0x143f /*Lightwell Co Ltd - Zax Division*/
#define VENDOR_ALGOL		0x1440 /*ALGOL Corp.*/
#define VENDOR_AGIE		0x1441 /*AGIE Ltd*/
#define VENDOR_PHOENIX3		0x1442 /*Phoenix Contact GmbH & Co.*/
#define VENDOR_UNIBRAIN		0x1443 /*Unibrain S.A.*/
#define VENDOR_TRW		0x1444 /*TRW*/
#define VENDOR_LOGICAL		0x1445 /*Logical DO Ltd*/
#define VENDOR_GRAPHIN		0x1446 /*Graphin Co Ltd*/
#define VENDOR_AIM		0x1447 /*AIM GmBH*/
#define VENDOR_ALESIS		0x1448 /*Alesis Studio Electronics*/
#define VENDOR_TUT		0x1449 /*TUT Systems Inc*/
#define VENDOR_ADLINK		0x144a /*Adlink Technology*/
#define VENDOR_LORONIX		0x144b /*Loronix Information Systems Inc*/
#define VENDOR_CATALINA		0x144c /*Catalina Research Inc*/
#define VENDOR_SAMSUNG5		0x144d /*Samsung Electronics Co Ltd*/
#define VENDOR_OLITEC		0x144e /*OLITEC*/
#define VENDOR_ASKEY		0x144f /*Askey Computer Corp.*/
#define VENDOR_OCTAVE		0x1450 /*Octave Communications Ind.*/
#define VENDOR_SP3D		0x1451 /*SP3D Chip Design GmBH*/
#define VENDOR_MYCOM		0x1453 /*MYCOM Inc*/
#define VENDOR_ALTIGA		0x1454 /*Altiga Networks*/
#define VENDOR_LOGIC2		0x1455 /*Logic Plus Plus Inc*/
#define VENDOR_ADVANCED9	0x1456 /*Advanced Hardware Architectures*/
#define VENDOR_NUERA		0x1457 /*Nuera Communications Inc*/
#define VENDOR_GIGA_BYTE	0x1458 /*Giga-byte Technology*/
#define VENDOR_DOOIN		0x1459 /*DOOIN Electronics*/
#define VENDOR_ESCALATE		0x145a /*Escalate Networks Inc*/
#define VENDOR_PRAIM		0x145b /*PRAIM SRL*/
#define VENDOR_CRYPTEK		0x145c /*Cryptek*/
#define VENDOR_GALLANT		0x145d /*Gallant Computer Inc*/
#define VENDOR_AASHIMA		0x145e /*Aashima Technology B.V.*/
#define VENDOR_BALDOR		0x145f /*Baldor Electric Company*/
#define VENDOR_DYNARC		0x1460 /*DYNARC INC*/
#define VENDOR_AVERMEDIA	0x1461 /*Avermedia Technologies Inc*/
#define VENDOR_MICRO_STAR	0x1462 /*Micro-Star International Co., Ltd.*/
#define VENDOR_FAST2		0x1463 /*Fast Corporation*/
#define VENDOR_INTERACTIVE2	0x1464 /*Interactive Circuits & Systems Ltd*/
#define VENDOR_GN_NETTEST	0x1465 /*GN NETTEST Telecom DIV.*/
#define VENDOR_DESIGNPRO	0x1466 /*Designpro Inc.*/
#define VENDOR_DIGICOM2		0x1467 /*DIGICOM SPA*/
#define VENDOR_AMBIT		0x1468 /*AMBIT Microsystem Corp.*/
#define VENDOR_CLEVELAND	0x1469 /*Cleveland Motion Controls*/
#define VENDOR_IFR		0x146a /*IFR*/
#define VENDOR_PARASCAN		0x146b /*Parascan Technologies Ltd*/
#define VENDOR_RUBY		0x146c /*Ruby Tech Corp.*/
#define VENDOR_TACHYON		0x146d /*Tachyon, INC.*/
#define VENDOR_WILLIAMS		0x146e /*Williams Electronics Games, Inc.*/
#define VENDOR_MULTI		0x146f /*Multi Dimensional Consulting Inc*/
#define VENDOR_BAY		0x1470 /*Bay Networks*/
#define VENDOR_INTEGRATED8	0x1471 /*Integrated Telecom Express Inc*/
#define VENDOR_DAIKIN		0x1472 /*DAIKIN Industries, Ltd*/
#define VENDOR_ZAPEX		0x1473 /*ZAPEX Technologies Inc*/
#define VENDOR_DOUG		0x1474 /*Doug Carson & Associates*/
#define VENDOR_PICAZO		0x1475 /*PICAZO Communications*/
#define VENDOR_MORTARA		0x1476 /*MORTARA Instrument Inc*/
#define VENDOR_NET		0x1477 /*Net Insight*/
#define VENDOR_DIATREND		0x1478 /*DIATREND Corporation*/
#define VENDOR_TORAY		0x1479 /*TORAY Industries Inc*/
#define VENDOR_FORMOSA		0x147a /*FORMOSA Industrial Computing*/
#define VENDOR_ABIT		0x147b /*ABIT Computer Corp.*/
#define VENDOR_AWARE		0x147c /*AWARE, Inc.*/
#define VENDOR_INTERWORKS	0x147d /*Interworks Computer Products*/
#define VENDOR_MATSUSHITA4	0x147e /*Matsushita Graphic Communication Systems, Inc.*/
#define VENDOR_NIHON		0x147f /*NIHON UNISYS, Ltd.*/
#define VENDOR_SCII		0x1480 /*SCII Telecom*/
#define VENDOR_BIOPAC		0x1481 /*BIOPAC Systems Inc*/
#define VENDOR_ISYTEC		0x1482 /*ISYTEC - Integrierte Systemtechnik GmBH*/
#define VENDOR_LABWAY		0x1483 /*LABWAY Corporation*/
#define VENDOR_LOGIC3		0x1484 /*Logic Corporation*/
#define VENDOR_ERMA		0x1485 /*ERMA - Electronic GmBH*/
#define VENDOR_L3_COMMUNICATIONS	0x1486 /*L3 Communications Telemetry & Instrumentation*/
#define VENDOR_MARQUETTE	0x1487 /*MARQUETTE Medical Systems*/
#define VENDOR_KONTRON		0x1488 /*KONTRON Electronik GmBH*/
#define VENDOR_KYE		0x1489 /*KYE Systems Corporation*/
#define VENDOR_OPTO		0x148a /*OPTO*/
#define VENDOR_INNOMEDIALOGIC	0x148b /*INNOMEDIALOGIC Inc.*/
#define VENDOR_C_P		0x148c /*C.P. Technology Co. Ltd*/
#define VENDOR_DIGICOM3		0x148d /*DIGICOM Systems, Inc.*/
#define VENDOR_OSI		0x148e /*OSI Plus Corporation*/
#define VENDOR_PLANT		0x148f /*Plant Equipment, Inc.*/
#define VENDOR_STONE		0x1490 /*Stone Microsystems PTY Ltd.*/
#define VENDOR_ZEAL		0x1491 /*ZEAL Corporation*/
#define VENDOR_TIME		0x1492 /*Time Logic Corporation*/
#define VENDOR_MAKER		0x1493 /*MAKER Communications*/
#define VENDOR_WINTOP		0x1494 /*WINTOP Technology, Inc.*/
#define VENDOR_TOKAI		0x1495 /*TOKAI Communications Industry Co. Ltd*/
#define VENDOR_JOYTECH		0x1496 /*JOYTECH Computer Co., Ltd.*/
#define VENDOR_SMA		0x1497 /*SMA Regelsysteme GmBH*/
#define VENDOR_TEWS		0x1498 /*TEWS Datentechnik GmBH*/
#define VENDOR_EMTEC		0x1499 /*EMTEC CO., Ltd*/
#define VENDOR_ANDOR		0x149a /*ANDOR Technology Ltd*/
#define VENDOR_SEIKO2		0x149b /*SEIKO Instruments Inc*/
#define VENDOR_OVISLINK		0x149c /*OVISLINK Corp.*/
#define VENDOR_NEWTEK		0x149d /*NEWTEK Inc*/
#define VENDOR_MAPLETREE	0x149e /*Mapletree Networks Inc.*/
#define VENDOR_LECTRON		0x149f /*LECTRON Co Ltd*/
#define VENDOR_SOFTING		0x14a0 /*SOFTING GmBH*/
#define VENDOR_SYSTEMBASE	0x14a1 /*Systembase Co Ltd*/
#define VENDOR_MILLENNIUM	0x14a2 /*Millennium Engineering Inc*/
#define VENDOR_MAVERICK		0x14a3 /*Maverick Networks*/
#define VENDOR_GVC_BCM		0x14a4 /*GVC/BCM Advanced Research*/
#define VENDOR_XIONICS		0x14a5 /*XIONICS Document Technologies Inc*/
#define VENDOR_INOVA		0x14a6 /*INOVA Computers GmBH & Co KG*/
#define VENDOR_MYTHOS		0x14a7 /*MYTHOS Systems Inc*/
#define VENDOR_FEATRON		0x14a8 /*FEATRON Technologies Corporation*/
#define VENDOR_HIVERTEC		0x14a9 /*HIVERTEC Inc*/
#define VENDOR_ADVANCED10	0x14aa /*Advanced MOS Technology Inc*/
#define VENDOR_MENTOR		0x14ab /*Mentor Graphics Corp.*/
#define VENDOR_NOVAWEB		0x14ac /*Novaweb Technologies Inc*/
#define VENDOR_TIME2		0x14ad /*Time Space Radio AB*/
#define VENDOR_CTI		0x14ae /*CTI, Inc*/
#define VENDOR_GUILLEMOT	0x14af /*Guillemot Corporation*/
#define VENDOR_BST		0x14b0 /*BST Communication Technology Ltd*/
#define VENDOR_NEXTCOM		0x14b1 /*Nextcom K.K.*/
#define VENDOR_ENNOVATE		0x14b2 /*ENNOVATE Networks Inc*/
#define VENDOR_XPEED		0x14b3 /*XPEED Inc*/
#define VENDOR_PHILIPS2		0x14b4 /*PHILIPS Business Electronics B.V.*/
#define VENDOR_CREAMWARE	0x14b5 /*Creamware GmBH*/
#define VENDOR_QUANTUM4		0x14b6 /*Quantum Data Corp.*/
#define VENDOR_PROXIM		0x14b7 /*PROXIM Inc*/
#define VENDOR_TECHSOFT		0x14b8 /*Techsoft Technology Co Ltd*/
#define VENDOR_AIRONET		0x14b9 /*AIRONET Wireless Communications*/
#define VENDOR_INTERNIX		0x14ba /*INTERNIX Inc.*/
#define VENDOR_SEMTECH		0x14bb /*SEMTECH Corporation*/
#define VENDOR_GLOBESPAN	0x14bc /*Globespan Semiconductor Inc.*/
#define VENDOR_CARDIO		0x14bd /*CARDIO Control N.V.*/
#define VENDOR_L3_COMMUNICATIONS2	0x14be /*L3 Communications*/
#define VENDOR_SPIDER		0x14bf /*SPIDER Communications Inc.*/
#define VENDOR_COMPAL		0x14c0 /*COMPAL Electronics Inc*/
#define VENDOR_MYRICOM		0x14c1 /*MYRICOM Inc.*/
#define VENDOR_DTK		0x14c2 /*DTK Computer*/
#define VENDOR_MEDIATEK		0x14c3 /*MEDIATEK Corp.*/
#define VENDOR_IWASAKI		0x14c4 /*IWASAKI Information Systems Co Ltd*/
#define VENDOR_AUTOMATION	0x14c5 /*Automation Products AB*/
#define VENDOR_DATA5		0x14c6 /*Data Race Inc*/
#define VENDOR_MODULAR		0x14c7 /*Modular Technology Holdings Ltd*/
#define VENDOR_TURBOCOMM	0x14c8 /*Turbocomm Tech. Inc.*/
#define VENDOR_ODIN		0x14c9 /*ODIN Telesystems Inc*/
#define VENDOR_PE_LOGIC		0x14ca /*PE Logic Corp.*/
#define VENDOR_BILLIONTON	0x14cb /*Billionton Systems Inc*/
#define VENDOR_NAKAYO		0x14cc /*NAKAYO Telecommunications Inc*/
#define VENDOR_UNIVERSAL	0x14cd /*Universal Scientific Ind.*/
#define VENDOR_WHISTLE		0x14ce /*Whistle Communications*/
#define VENDOR_TEK		0x14cf /*TEK Microsystems Inc.*/
#define VENDOR_ERICSSON		0x14d0 /*Ericsson Axe R & D*/
#define VENDOR_COMPUTER3	0x14d1 /*Computer Hi-Tech Co Ltd*/
#define VENDOR_TITAN		0x14d2 /*Titan Electronics Inc*/
#define VENDOR_CIRTECH		0x14d3 /*CIRTECH (UK) Ltd*/
#define VENDOR_PANACOM		0x14d4 /*Panacom Technology Corp*/
#define VENDOR_NITSUKO		0x14d5 /*Nitsuko Corporation*/
#define VENDOR_ACCUSYS		0x14d6 /*Accusys Inc*/
#define VENDOR_HIRAKAWA		0x14d7 /*Hirakawa Hewtech Corp*/
#define VENDOR_HOPF		0x14d8 /*HOPF Elektronik GmBH*/
#define VENDOR_ALLIANCE2	0x14d9 /*Alliance Semiconductor Corporation*/
#define VENDOR_NATIONAL3	0x14da /*National Aerospace Laboratories*/
#define VENDOR_AFAVLAB		0x14db /*AFAVLAB Technology Inc*/
#define VENDOR_AMPLICON		0x14dc /*Amplicon Liveline Ltd*/
#define VENDOR_BOULDER		0x14dd /*Boulder Design Labs Inc*/
#define VENDOR_APPLIED4		0x14de /*Applied Integration Corporation*/
#define VENDOR_ASIC		0x14df /*ASIC Communications Corp*/
#define VENDOR_INVERTEX		0x14e1 /*INVERTEX*/
#define VENDOR_INFOLIBRIA	0x14e2 /*INFOLIBRIA*/
#define VENDOR_AMTELCO		0x14e3 /*AMTELCO*/
#define VENDOR_BROADCOM		0x14e4 /*Broadcom Corporation*/
#define VENDOR_PIXELFUSION	0x14e5 /*Pixelfusion Ltd*/
#define VENDOR_SHINING		0x14e6 /*SHINING Technology Inc*/
#define VENDOR_3CX		0x14e7 /*3CX*/
#define VENDOR_RAYCER		0x14e8 /*RAYCER Inc*/
#define VENDOR_GARNETS		0x14e9 /*GARNETS System CO Ltd*/
#define VENDOR_PLANEX		0x14ea /*Planex Communications, Inc*/
#define VENDOR_SEIKO3		0x14eb /*SEIKO EPSON Corp*/
#define VENDOR_ACQIRIS		0x14ec /*ACQIRIS*/
#define VENDOR_DATAKINETICS	0x14ed /*DATAKINETICS Ltd*/
#define VENDOR_MASPRO		0x14ee /*MASPRO KENKOH Corp*/
#define VENDOR_CARRY		0x14ef /*CARRY Computer ENG. CO Ltd*/
#define VENDOR_CANON3		0x14f0 /*CANON RESEACH CENTRE FRANCE*/
#define VENDOR_CONEXANT		0x14f1 /*Conexant*/
#define VENDOR_MOBILITY		0x14f2 /*MOBILITY Electronics*/
#define VENDOR_BROADLOGIC	0x14f3 /*BroadLogic*/
#define VENDOR_TOKYO		0x14f4 /*TOKYO Electronic Industry CO Ltd*/
#define VENDOR_SOPAC		0x14f5 /*SOPAC Ltd*/
#define VENDOR_COYOTE		0x14f6 /*COYOTE Technologies LLC*/
#define VENDOR_WOLF		0x14f7 /*WOLF Technology Inc*/
#define VENDOR_AUDIOCODES	0x14f8 /*AUDIOCODES Inc*/
#define VENDOR_AG_COMMUNICATIONS	0x14f9 /*AG COMMUNICATIONS*/
#define VENDOR_WANDEL		0x14fa /*WANDEL & GOCHERMANN*/
#define VENDOR_TRANSAS		0x14fb /*TRANSAS MARINE (UK) Ltd*/
#define VENDOR_QUADRICS		0x14fc /*Quadrics Ltd*/
#define VENDOR_JAPAN2		0x14fd /*JAPAN Computer Industry Inc*/
#define VENDOR_ARCHTEK		0x14fe /*ARCHTEK TELECOM Corp*/
#define VENDOR_TWINHEAD		0x14ff /*TWINHEAD INTERNATIONAL Corp*/
#define VENDOR_DELTA		0x1500 /*DELTA Electronics, Inc*/
#define VENDOR_BANKSOFT		0x1501 /*BANKSOFT CANADA Ltd*/
#define VENDOR_MITSUBISHI4	0x1502 /*MITSUBISHI ELECTRIC LOGISTICS SUPPORT Co Ltd*/
#define VENDOR_KAWASAKI3	0x1503 /*KAWASAKI LSI USA Inc*/
#define VENDOR_KAISER		0x1504 /*KAISER Electronics*/
#define VENDOR_ITA		0x1505 /*ITA INGENIEURBURO FUR TESTAUFGABEN GmbH*/
#define VENDOR_CHAMELEON	0x1506 /*CHAMELEON Systems Inc*/
#define VENDOR_MOTOROLA3	0x1507 /*Motorola ?? / HTEC*/
#define VENDOR_HONDA		0x1508 /*HONDA CONNECTORS/MHOTRONICS Inc*/
#define VENDOR_FIRST3		0x1509 /*FIRST INTERNATIONAL Computer Inc*/
#define VENDOR_FORVUS		0x150a /*FORVUS RESEARCH Inc*/
#define VENDOR_YAMASHITA	0x150b /*YAMASHITA Systems Corp*/
#define VENDOR_KYOPAL		0x150c /*KYOPAL CO Ltd*/
#define VENDOR_WARPSPPED	0x150d /*WARPSPPED Inc*/
#define VENDOR_C_PORT		0x150e /*C-PORT Corp*/
#define VENDOR_INTEC		0x150f /*INTEC GmbH*/
#define VENDOR_BEHAVIOR		0x1510 /*BEHAVIOR TECH Computer Corp*/
#define VENDOR_CENTILLIUM	0x1511 /*CENTILLIUM Technology Corp*/
#define VENDOR_ROSUN		0x1512 /*ROSUN Technologies Inc*/
#define VENDOR_RAYCHEM		0x1513 /*Raychem*/
#define VENDOR_TFL		0x1514 /*TFL LAN Inc*/
#define VENDOR_ADVENT		0x1515 /*Advent design*/
#define VENDOR_MYSON		0x1516 /*MYSON Technology Inc*/
#define VENDOR_ECHOTEK		0x1517 /*ECHOTEK Corp*/
#define VENDOR_PEP		0x1518 /*PEP MODULAR Computers GmbH*/
#define VENDOR_TELEFON		0x1519 /*TELEFON AKTIEBOLAGET LM Ericsson*/
#define VENDOR_GLOBETEK		0x151a /*Globetek*/
#define VENDOR_COMBOX		0x151b /*COMBOX Ltd*/
#define VENDOR_DIGITAL3		0x151c /*DIGITAL AUDIO LABS Inc*/
#define VENDOR_FUJITSU4		0x151d /*Fujitsu Computer Products Of America*/
#define VENDOR_MATRIX		0x151e /*MATRIX Corp*/
#define VENDOR_TOPIC		0x151f /*TOPIC SEMICONDUCTOR Corp*/
#define VENDOR_CHAPLET		0x1520 /*CHAPLET System Inc*/
#define VENDOR_BELL		0x1521 /*BELL Corp*/
#define VENDOR_MAINPINE		0x1522 /*MainPine Ltd*/
#define VENDOR_MUSIC		0x1523 /*MUSIC Semiconductors*/
#define VENDOR_ENE		0x1524 /*ENE Technology Inc*/
#define VENDOR_IMPACT		0x1525 /*IMPACT Technologies*/
#define VENDOR_ISS		0x1526 /*ISS, Inc*/
#define VENDOR_SOLECTRON	0x1527 /*SOLECTRON*/
#define VENDOR_ACKSYS		0x1528 /*ACKSYS*/
#define VENDOR_AMERICAN2	0x1529 /*AMERICAN MICROSystems Inc*/
#define VENDOR_QUICKTURN	0x152a /*QUICKTURN DESIGN Systems*/
#define VENDOR_FLYTECH		0x152b /*FLYTECH Technology CO Ltd*/
#define VENDOR_MACRAIGOR	0x152c /*MACRAIGOR Systems LLC*/
#define VENDOR_QUANTA		0x152d /*QUANTA Computer Inc*/
#define VENDOR_MELEC		0x152e /*MELEC Inc*/
#define VENDOR_PHILIPS3		0x152f /*PHILIPS - CRYPTO*/
#define VENDOR_ACQIS		0x1530 /*ACQIS Technology Inc*/
#define VENDOR_CHRYON		0x1531 /*CHRYON Corp*/
#define VENDOR_ECHELON		0x1532 /*ECHELON Corp*/
#define VENDOR_BALTIMORE	0x1533 /*BALTIMORE*/
#define VENDOR_ROAD		0x1534 /*ROAD Corp*/
#define VENDOR_EVERGREEN	0x1535 /*EVERGREEN Technologies Inc*/
#define VENDOR_DATALEX		0x1537 /*DATALEX COMMUNCATIONS*/
#define VENDOR_ARALION		0x1538 /*ARALION Inc*/
#define VENDOR_ATELIER		0x1539 /*ATELIER INFORMATIQUES et ELECTRONIQUE ETUDES S.A.*/
#define VENDOR_ONO		0x153a /*ONO SOKKI*/
#define VENDOR_TERRATEC		0x153b /*TERRATEC Electronic GmbH*/
#define VENDOR_ANTAL		0x153c /*ANTAL Electronic*/
#define VENDOR_FILANET		0x153d /*FILANET Corp*/
#define VENDOR_TECHWELL		0x153e /*TECHWELL Inc*/
#define VENDOR_MIPS		0x153f /*MIPS DENMARK*/
#define VENDOR_PROVIDEO		0x1540 /*PROVIDEO MULTIMEDIA Co Ltd*/
#define VENDOR_MACHONE		0x1541 /*MACHONE Communications*/
#define VENDOR_VIVID		0x1542 /*VIVID Technology Inc*/
#define VENDOR_SILICON11	0x1543 /*SILICON Laboratories*/
#define VENDOR_DCM		0x1544 /*DCM DATA Systems*/
#define VENDOR_VISIONTEK	0x1545 /*VISIONTEK*/
#define VENDOR_IOI		0x1546 /*IOI Technology Corp*/
#define VENDOR_MITUTOYO		0x1547 /*MITUTOYO Corp*/
#define VENDOR_JET		0x1548 /*JET PROPULSION Laboratory*/
#define VENDOR_INTERCONNECT	0x1549 /*INTERCONNECT Systems Solutions*/
#define VENDOR_MAX		0x154a /*MAX Technologies Inc*/
#define VENDOR_COMPUTEX		0x154b /*COMPUTEX Co Ltd*/
#define VENDOR_VISUAL		0x154c /*VISUAL Technology Inc*/
#define VENDOR_PAN		0x154d /*PAN INTERNATIONAL Industrial Corp*/
#define VENDOR_SERVOTEST	0x154e /*SERVOTEST Ltd*/
#define VENDOR_STRATABEAM	0x154f /*STRATABEAM Technology*/
#define VENDOR_OPEN		0x1550 /*OPEN NETWORK Co Ltd*/
#define VENDOR_SMART2		0x1551 /*SMART Electronic DEVELOPMENT GmBH*/
#define VENDOR_RACAL		0x1552 /*RACAL AIRTECH Ltd*/
#define VENDOR_CHICONY		0x1553 /*CHICONY Electronics Co Ltd*/
#define VENDOR_PROLINK		0x1554 /*PROLINK Microsystems Corp*/
#define VENDOR_GESYTEC		0x1555 /*GESYTEC GmBH*/
#define VENDOR_PLD		0x1556 /*PLD APPLICATIONS*/
#define VENDOR_MEDIASTAR	0x1557 /*MEDIASTAR Co Ltd*/
#define VENDOR_CLEVO_KAPOK	0x1558 /*CLEVO/KAPOK Computer*/
#define VENDOR_SI_LOGIC		0x1559 /*SI LOGIC Ltd*/
#define VENDOR_INNOMEDIA	0x155a /*INNOMEDIA Inc*/
#define VENDOR_PROTAC		0x155b /*PROTAC INTERNATIONAL Corp*/
#define VENDOR_CEMAX_ICON	0x155c /*Cemax-Icon Inc*/
#define VENDOR_MAC		0x155d /*Mac System Co Ltd*/
#define VENDOR_LP_ELEKTRONIK	0x155e /*LP Elektronik GmbH*/
#define VENDOR_PERLE		0x155f /*Perle Systems Ltd*/
#define VENDOR_TERAYON		0x1560 /*Terayon Communications Systems*/
#define VENDOR_VIEWGRAPHICS	0x1561 /*Viewgraphics Inc*/
#define VENDOR_SYMBOL		0x1562 /*Symbol Technologies*/
#define VENDOR_A_TREND2		0x1563 /*A-Trend Technology Co Ltd*/
#define VENDOR_YAMAKATSU	0x1564 /*Yamakatsu Electronics Industry Co Ltd*/
#define VENDOR_BIOSTAR		0x1565 /*Biostar Microtech Int'l Corp*/
#define VENDOR_ARDENT		0x1566 /*Ardent Technologies Inc*/
#define VENDOR_JUNGSOFT		0x1567 /*Jungsoft*/
#define VENDOR_DDK		0x1568 /*DDK Electronics Inc*/
#define VENDOR_PALIT		0x1569 /*Palit Microsystems Inc.*/
#define VENDOR_AVTEC		0x156a /*Avtec Systems*/
#define VENDOR_2WIRE		0x156b /*2wire Inc*/
#define VENDOR_VIDAC		0x156c /*Vidac Electronics GmbH*/
#define VENDOR_ALPHA_TOP	0x156d /*Alpha-Top Corp*/
#define VENDOR_ALFA2		0x156e /*Alfa Inc*/
#define VENDOR_M_SYSTEMS	0x156f /*M-Systems Flash Disk Pioneers Ltd*/
#define VENDOR_LECROY		0x1570 /*Lecroy Corp*/
#define VENDOR_CONTEMPORARY	0x1571 /*Contemporary Controls*/
#define VENDOR_OTIS		0x1572 /*Otis Elevator Company*/
#define VENDOR_LATTICE2		0x1573 /*Lattice - Vantis*/
#define VENDOR_FAIRCHILD	0x1574 /*Fairchild Semiconductor*/
#define VENDOR_VOLTAIRE		0x1575 /*Voltaire Advanced Data Security Ltd*/
#define VENDOR_VIEWCAST		0x1576 /*Viewcast COM*/
#define VENDOR_HITT		0x1578 /*HITT*/
#define VENDOR_DUAL		0x1579 /*Dual Technology Corp*/
#define VENDOR_JAPAN3		0x157a /*Japan Elecronics Ind Inc*/
#define VENDOR_STAR		0x157b /*Star Multimedia Corp*/
#define VENDOR_EUROSOFT		0x157c /*Eurosoft (UK)*/
#define VENDOR_GEMFLEX		0x157d /*Gemflex Networks*/
#define VENDOR_TRANSITION	0x157e /*Transition Networks*/
#define VENDOR_PX_INSTRUMENTS	0x157f /*PX Instruments Technology Ltd*/
#define VENDOR_PRIMEX		0x1580 /*Primex Aerospace Co*/
#define VENDOR_SEH		0x1581 /*SEH Computertechnik GmbH*/
#define VENDOR_CYTEC		0x1582 /*Cytec Corp*/
#define VENDOR_INET		0x1583 /*Inet Technologies Inc*/
#define VENDOR_UNIWILL		0x1584 /*Uniwill Computer Corp*/
#define VENDOR_LOGITRON		0x1585 /*Logitron*/
#define VENDOR_LANCAST		0x1586 /*Lancast Inc*/
#define VENDOR_KONICA		0x1587 /*Konica Corp*/
#define VENDOR_SOLIDUM		0x1588 /*Solidum Systems Corp*/
#define VENDOR_ATLANTEK		0x1589 /*Atlantek Microsystems Pty Ltd*/
#define VENDOR_DIGALOG		0x158a /*Digalog Systems Inc*/
#define VENDOR_ALLIED2		0x158b /*Allied Data Technologies*/
#define VENDOR_HITACHI7		0x158c /*Hitachi Semiconductor & Devices Sales Co Ltd*/
#define VENDOR_POINT		0x158d /*Point Multimedia Systems*/
#define VENDOR_LARA		0x158e /*Lara Technology Inc*/
#define VENDOR_DITECT		0x158f /*Ditect Coop*/
#define VENDOR_3PARDATA		0x1590 /*3pardata Inc*/
#define VENDOR_ARN		0x1591 /*ARN*/
#define VENDOR_SYBA		0x1592 /*Syba Tech Ltd*/
#define VENDOR_BOPS		0x1593 /*Bops Inc*/
#define VENDOR_NETGAME		0x1594 /*Netgame Ltd*/
#define VENDOR_DIVA		0x1595 /*Diva Systems Corp*/
#define VENDOR_FOLSOM		0x1596 /*Folsom Research Inc*/
#define VENDOR_MEMEC		0x1597 /*Memec Design Services*/
#define VENDOR_GRANITE2		0x1598 /*Granite Microsystems*/
#define VENDOR_DELTA2		0x1599 /*Delta Electronics Inc*/
#define VENDOR_GENERAL2		0x159a /*General Instrument*/
#define VENDOR_FARADAY		0x159b /*Faraday Technology Corp*/
#define VENDOR_STRATUS2		0x159c /*Stratus Computer Systems*/
#define VENDOR_NINGBO		0x159d /*Ningbo Harrison Electronics Co Ltd*/
#define VENDOR_A_MAX		0x159e /*A-Max Technology Co Ltd*/
#define VENDOR_GALEA		0x159f /*Galea Network Security*/
#define VENDOR_COMPUMASTER	0x15a0 /*Compumaster SRL*/
#define VENDOR_GEOCAST		0x15a1 /*Geocast Network Systems*/
#define VENDOR_CATALYST		0x15a2 /*Catalyst Enterprises Inc*/
#define VENDOR_ITALTEL		0x15a3 /*Italtel*/
#define VENDOR_X_NET		0x15a4 /*X-Net OY*/
#define VENDOR_TOYOTA		0x15a5 /*Toyota Macs Inc*/
#define VENDOR_SUNLIGHT		0x15a6 /*Sunlight Ultrasound Technologies Ltd*/
#define VENDOR_SSE		0x15a7 /*SSE Telecom Inc*/
#define VENDOR_SHANGHAI		0x15a8 /*Shanghai Communications Technologies Center*/
#define VENDOR_MORETON		0x15aa /*Moreton Bay*/
#define VENDOR_BLUESTEEL	0x15ab /*Bluesteel Networks Inc*/
#define VENDOR_NORTH		0x15ac /*North Atlantic Instruments*/
#define VENDOR_VMWARE		0x15ad /*VMware Inc*/
#define VENDOR_AMERSHAM		0x15ae /*Amersham Pharmacia Biotech*/
#define VENDOR_ZOLTRIX		0x15b0 /*Zoltrix International Ltd*/
#define VENDOR_SOURCE		0x15b1 /*Source Technology Inc*/
#define VENDOR_MOSAID		0x15b2 /*Mosaid Technologies Inc*/
#define VENDOR_MELLANOX		0x15b3 /*Mellanox Technologies*/
#define VENDOR_CCI_TRIAD	0x15b4 /*CCI/TRIAD*/
#define VENDOR_CIMETRICS	0x15b5 /*Cimetrics Inc*/
#define VENDOR_TEXAS3		0x15b6 /*Texas Memory Systems Inc*/
#define VENDOR_SANDISK		0x15b7 /*Sandisk Corp*/
#define VENDOR_ADDI_DATA	0x15b8 /*ADDI-DATA GmbH*/
#define VENDOR_MAESTRO		0x15b9 /*Maestro Digital Communications*/
#define VENDOR_IMPACCT		0x15ba /*Impacct Technology Corp*/
#define VENDOR_PORTWELL		0x15bb /*Portwell Inc*/
#define VENDOR_AGILENT		0x15bc /*Agilent Technologies*/
#define VENDOR_DFI2		0x15bd /*DFI Inc*/
#define VENDOR_SOLA		0x15be /*Sola Electronics*/
#define VENDOR_HIGH3		0x15bf /*High Tech Computer Corp (HTC)*/
#define VENDOR_BVM		0x15c0 /*BVM Ltd*/
#define VENDOR_QUANTEL		0x15c1 /*Quantel*/
#define VENDOR_NEWER		0x15c2 /*Newer Technology Inc*/
#define VENDOR_TAIWAN		0x15c3 /*Taiwan Mycomp Co Ltd*/
#define VENDOR_EVSX		0x15c4 /*EVSX Inc*/
#define VENDOR_PROCOMP		0x15c5 /*Procomp Informatics Ltd*/
#define VENDOR_TECHNICAL3	0x15c6 /*Technical University of Budapest*/
#define VENDOR_TATEYAMA		0x15c7 /*Tateyama System Laboratory Co Ltd*/
#define VENDOR_PENTA		0x15c8 /*Penta Media Co Ltd*/
#define VENDOR_SEROME		0x15c9 /*Serome Technology Inc*/
#define VENDOR_BITBOYS		0x15ca /*Bitboys OY*/
#define VENDOR_AG_ELECTRONICS	0x15cb /*AG Electronics Ltd*/
#define VENDOR_HOTRAIL		0x15cc /*Hotrail Inc*/
#define VENDOR_DREAMTECH	0x15cd /*Dreamtech Co Ltd*/
#define VENDOR_GENRAD		0x15ce /*Genrad Inc*/
#define VENDOR_HILSCHER		0x15cf /*Hilscher GmbH*/
#define VENDOR_INFINEON		0x15d1 /*Infineon Technologies AG*/
#define VENDOR_FIC		0x15d2 /*FIC (First International Computer Inc)*/
#define VENDOR_NDS		0x15d3 /*NDS Technologies Israel Ltd*/
#define VENDOR_IWILL		0x15d4 /*Iwill Corp*/
#define VENDOR_TATUNG2		0x15d5 /*Tatung Co*/
#define VENDOR_ENTRIDIA		0x15d6 /*Entridia Corp*/
#define VENDOR_ROCKWELL_COLLINS	0x15d7 /*Rockwell-Collins Inc*/
#define VENDOR_CYBERNETICS	0x15d8 /*Cybernetics Technology Co Ltd*/
#define VENDOR_SUPER		0x15d9 /*Super Micro Computer Inc*/
#define VENDOR_CYBERFIRM	0x15da /*Cyberfirm Inc*/
#define VENDOR_APPLIED5		0x15db /*Applied Computing Systems Inc*/
#define VENDOR_LITRONIC		0x15dc /*Litronic Inc*/
#define VENDOR_SIGMATEL		0x15dd /*Sigmatel Inc*/
#define VENDOR_MALLEABLE	0x15de /*Malleable Technologies Inc*/
#define VENDOR_INFINILINK	0x15df /*Infinilink Corp*/
#define VENDOR_CACHEFLOW	0x15e0 /*Cacheflow Inc*/
#define VENDOR_VOICE		0x15e1 /*Voice Technologies Group Inc*/
#define VENDOR_QUICKNET		0x15e2 /*Quicknet Technologies Inc*/
#define VENDOR_NETWORTH2	0x15e3 /*Networth Technologies Inc*/
#define VENDOR_VSN		0x15e4 /*VSN Systemen BV*/
#define VENDOR_VALLEY		0x15e5 /*Valley technologies Inc*/
#define VENDOR_AGERE2		0x15e6 /*Agere Inc*/
#define VENDOR_GET		0x15e7 /*Get Engineering Corp*/
#define VENDOR_NATIONAL4	0x15e8 /*National Datacomm Corp*/
#define VENDOR_PACIFIC		0x15e9 /*Pacific Digital Corp*/
#define VENDOR_TOKYO2		0x15ea /*Tokyo Denshi Sekei K.K.*/
#define VENDOR_DRSEARCH		0x15eb /*Drsearch GmbH*/
#define VENDOR_BECKHOFF		0x15ec /*Beckhoff GmbH*/
#define VENDOR_MACROLINK	0x15ed /*Macrolink Inc*/
#define VENDOR_IN_WIN		0x15ee /*In Win Development Inc*/
#define VENDOR_INTELLIGENT2	0x15ef /*Intelligent Paradigm Inc*/
#define VENDOR_B_TREE		0x15f0 /*B-Tree Systems Inc*/
#define VENDOR_TIMES		0x15f1 /*Times N Systems Inc*/
#define VENDOR_DIAGNOSTIC	0x15f2 /*Diagnostic Instruments Inc*/
#define VENDOR_DIGITMEDIA	0x15f3 /*Digitmedia Corp*/
#define VENDOR_VALUESOFT	0x15f4 /*Valuesoft*/
#define VENDOR_POWER3		0x15f5 /*Power Micro Research*/
#define VENDOR_EXTREME		0x15f6 /*Extreme Packet Device Inc*/
#define VENDOR_BANCTEC		0x15f7 /*Banctec*/
#define VENDOR_KOGA		0x15f8 /*Koga Electronics Co*/
#define VENDOR_ZENITH3		0x15f9 /*Zenith Electronics Corp*/
#define VENDOR_J_P		0x15fa /*J.P. Axzam Corp*/
#define VENDOR_ZILOG2		0x15fb /*Zilog Inc*/
#define VENDOR_TECHSAN2		0x15fc /*Techsan Electronics Co Ltd*/
#define VENDOR_N_CUBED_NET	0x15fd /*N-CUBED.NET*/
#define VENDOR_KINPO		0x15fe /*Kinpo Electronics Inc*/
#define VENDOR_FASTPOINT	0x15ff /*Fastpoint Technologies Inc*/
#define VENDOR_NORTHROP		0x1600 /*Northrop Grumman - Canada Ltd*/
#define VENDOR_TENTA		0x1601 /*Tenta Technology*/
#define VENDOR_PROSYS_TEC	0x1602 /*Prosys-tec Inc*/
#define VENDOR_NOKIA2		0x1603 /*Nokia Wireless Communications*/
#define VENDOR_CENTRAL2		0x1604 /*Central System Research Co Ltd*/
#define VENDOR_PAIRGAIN		0x1605 /*Pairgain Technologies*/
#define VENDOR_EUROPOP		0x1606 /*Europop AG*/
#define VENDOR_LAVA2		0x1607 /*Lava Semiconductor Manufacturing Inc*/
#define VENDOR_AUTOMATED	0x1608 /*Automated Wagering International*/
#define VENDOR_SCIMETRIC	0x1609 /*Scimetric Instruments Inc*/
#define VENDOR_TELESYNERGY	0x1612 /*Telesynergy Research Inc.*/
#define VENDOR_FARSITE		0x1619 /*FarSite Communications Ltd*/
#define VENDOR_RIOWORKS		0x161f /*Rioworks*/
#define VENDOR_TDK2		0x1626 /*TDK Semiconductor Corp.*/
#define VENDOR_KONGSBERG	0x1629 /*Kongsberg Spacetec AS*/
#define VENDOR_LINKSYS2		0x1637 /*Linksys*/
#define VENDOR_STANDARD2	0x1638 /*Standard Microsystems Corp [SMC]*/
#define VENDOR_SMART3		0x163c /*Smart Link Ltd.*/
#define VENDOR_BROCADE		0x1657 /*Brocade Communications Systems, Inc.*/
#define VENDOR_EPIX		0x165a /*Epix Inc*/
#define VENDOR_HSING		0x165d /*Hsing Tech. Enterprise Co., Ltd.*/
#define VENDOR_WORLDSPACE	0x1661 /*Worldspace Corp.*/
#define VENDOR_ACTIONTEC	0x1668 /*Actiontec Electronics Inc*/
#define VENDOR_BROADCOM2	0x166d /*Broadcom Corporation*/
#define VENDOR_BERNECKER	0x1677 /*Bernecker + Rainer*/
#define VENDOR_HERCULES		0x1681 /*Hercules*/
#define VENDOR_CASTLENET	0x1688 /*CastleNet Technology Inc.*/
#define VENDOR_ATHEROS		0x168c /*Atheros Communications, Inc.*/
#define VENDOR_TEKRAM2		0x16a5 /*Tekram Technology Co.,Ltd.*/
#define VENDOR_GLOBAL		0x16ab /*Global Sun Technology Inc*/
#define VENDOR_SAFENET		0x16ae /*Safenet Inc*/
#define VENDOR_ASPEX		0x16b4 /*Aspex Semiconductor Ltd*/
#define VENDOR_CREATIX		0x16be /*Creatix Polymedia GmbH*/
#define VENDOR_CENATEK		0x16ca /*CENATEK Inc*/
#define VENDOR_DENSITRON	0x16cd /*Densitron Technologies*/
#define VENDOR_PIKA		0x16df /*PIKA Technologies Inc.*/
#define VENDOR_EUROPEAN		0x16e3 /*European Space Agency*/
#define VENDOR_U_S		0x16ec /*U.S. Robotics*/
#define VENDOR_SYCRON		0x16ed /*Sycron N. V.*/
#define VENDOR_JETWAY		0x16f3 /*Jetway Information Co., Ltd.*/
#define VENDOR_VWEB		0x16f4 /*Vweb Corp*/
#define VENDOR_VIDEOTELE_COM	0x16f6 /*VideoTele.com, Inc.*/
#define VENDOR_INTERNET		0x1702 /*Internet Machines Corporation (IMC)*/
#define VENDOR_DIGITAL4		0x1705 /*Digital First, Inc.*/
#define VENDOR_NETOCTAVE	0x170b /*NetOctave*/
#define VENDOR_YOTTAYOTTA	0x170c /*YottaYotta Inc.*/
#define VENDOR_VITESSE2		0x1725 /*Vitesse Semiconductor*/
#define VENDOR_ACCELERATED	0x172a /*Accelerated Encryption*/
#define VENDOR_FUJITSU5		0x1734 /*Fujitsu Siemens Computer GmbH*/
#define VENDOR_LINKSYS3		0x1737 /*Linksys*/
#define VENDOR_ALTIMA		0x173b /*Altima (nee Broadcom)*/
#define VENDOR_PEPPERCON	0x1743 /*Peppercon AG*/
#define VENDOR_RLX		0x1749 /*RLX Technologies*/
#define VENDOR_PC_PARTNER	0x174b /*PC Partner Limited*/
#define VENDOR_WELLX		0x174d /*WellX Telecom SA*/
#define VENDOR_AUDIOSCIENCE	0x175c /*AudioScience Inc*/
#define VENDOR_SANERA		0x175e /*Sanera Systems, Inc.*/
#define VENDOR_HIGHTECH		0x1787 /*Hightech Information System Ltd.*/
#define VENDOR_RESEARCH		0x1796 /*Research Centre Juelich*/
#define VENDOR_JUMPTEC		0x1797 /*JumpTec h, GMBH*/
#define VENDOR_BELKIN		0x1799 /*Belkin*/
#define VENDOR_GENESYS		0x17a0 /*Genesys Logic, Inc*/
#define VENDOR_HIGHTECH2	0x17af /*Hightech Information System Ltd.*/
#define VENDOR_HAWKING		0x17b3 /*Hawking Technologies*/
#define VENDOR_INDRA		0x17b4 /*Indra Networks, Inc.*/
#define VENDOR_WISTRON		0x17c0 /*Wistron Corp.*/
#define VENDOR_NEWISYS		0x17c2 /*Newisys, Inc.*/
#define VENDOR_NETCHIP		0x17cc /*NetChip Technology, Inc*/
#define VENDOR_S2IO		0x17d5 /*S2io Inc.*/
#define VENDOR_CONNECT2		0x17ee /*Connect Components Ltd*/
#define VENDOR_LINKSYS4		0x17fe /*Linksys, A Division of Cisco Systems*/
#define VENDOR_AMBIENT		0x1813 /*Ambient Technologies Inc*/
#define VENDOR_RALINK		0x1814 /*RaLink*/
#define VENDOR_INFINICON	0x1820 /*InfiniCon Systems Inc.*/
#define VENDOR_TWINHAN		0x1822 /*Twinhan Technology Co. Ltd*/
#define VENDOR_SITECOM		0x182d /*SiteCom Europe BV*/
#define VENDOR_CREDENCE		0x1830 /*Credence Systems Corporation*/
#define VENDOR_MIKROM		0x183b /*MikroM GmbH*/
#define VENDOR_ASROCK		0x1849 /*ASRock Incorporation*/
#define VENDOR_MICROTUNE	0x1851 /*Microtune, Inc.*/
#define VENDOR_ANRITSU		0x1852 /*Anritsu Corp.*/
#define VENDOR_TOPSPIN		0x1867 /*Topspin Communications*/
#define VENDOR_VARISYS		0x1888 /*Varisys Ltd*/
#define VENDOR_KNC		0x1894 /*KNC One*/
#define VENDOR_B_B		0x1896 /*B&B Electronics Manufacturing Company, Inc.*/
#define VENDOR_ASTUTE		0x18a1 /*Astute Networks Inc.*/
#define VENDOR_DVICO		0x18ac /*DViCO Corporation*/
#define VENDOR_INFO_TEK		0x18bc /*Info-Tek Corp.*/
#define VENDOR_CRAY2		0x18c8 /*Cray Inc*/
#define VENDOR_ARVOO		0x18c9 /*ARVOO Engineering BV*/
#define VENDOR_XGI		0x18ca /*XGI - Xabre Graphics Inc*/
#define VENDOR_MPL		0x18e6 /*MPL AG*/
#define VENDOR_COMMTECH		0x18f7 /*Commtech, Inc.*/
#define VENDOR_RESILIENCE	0x18fb /*Resilience Corporation*/
#define VENDOR_SIERRA3		0x1a08 /*Sierra semiconductor*/
#define VENDOR_JATON		0x1b13 /*Jaton Corp*/
#define VENDOR_SYMPHONY2	0x1c1c /*Symphony*/
#define VENDOR_DPT		0x1d44 /*DPT*/
#define VENDOR_TEKRAM3		0x1de1 /*Tekram Technology Co.,Ltd.*/
#define VENDOR_TUMSAN		0x1fc0 /*Tumsan Oy*/
#define VENDOR_SMART4		0x2000 /*Smart Link Ltd.*/
#define VENDOR_TEMPORAL		0x2001 /*Temporal Research Ltd*/
#define VENDOR_SMART5		0x2003 /*Smart Link Ltd.*/
#define VENDOR_SMART6		0x2004 /*Smart Link Ltd.*/
#define VENDOR_21ST		0x21c3 /*21st Century Computer Corp.*/
#define VENDOR_RACORE2		0x2348 /*Racore*/
#define VENDOR_KINGSTON2	0x2646 /*Kingston Technologies*/
#define VENDOR_XANTEL		0x270b /*Xantel Corporation*/
#define VENDOR_CHAINTECH2	0x270f /*Chaintech Computer Co. Ltd*/
#define VENDOR_AVID2		0x2711 /*AVID Technology Inc.*/
#define VENDOR_3D_VISION	0x2a15 /*3D Vision(?)*/
#define VENDOR_HANSOL		0x3000 /*Hansol Electronics Inc.*/
#define VENDOR_POST		0x3142 /*Post Impression Systems.*/
#define VENDOR_HINT		0x3388 /*Hint Corp*/
#define VENDOR_QUANTUM5		0x3411 /*Quantum Designs (H.K.) Inc*/
#define VENDOR_ARCOM2		0x3513 /*ARCOM Control Systems Ltd*/
#define VENDOR_EVGA_COM		0x3842 /*eVga.com. Corp.*/
#define VENDOR_4LINKS		0x38ef /*4Links*/
#define VENDOR_3DLABS		0x3d3d /*3DLabs*/
#define VENDOR_AVANCE2		0x4005 /*Avance Logic Inc.*/
#define VENDOR_ADDTRON		0x4033 /*Addtron Technology Co, Inc.*/
#define VENDOR_DIGITAL5		0x4143 /*Digital Equipment Corp*/
#define VENDOR_ALPHA		0x4144 /*Alpha Data*/
#define VENDOR_ALADDIN		0x416c /*Aladdin Knowledge Systems*/
#define VENDOR_INTERNEXT	0x4444 /*Internext Compression Inc*/
#define VENDOR_BRIDGEPORT2	0x4468 /*Bridgeport machines*/
#define VENDOR_COGETEC		0x4594 /*Cogetec Informatique Inc*/
#define VENDOR_BALDOR2		0x45fb /*Baldor Electric Company*/
#define VENDOR_UMAX		0x4680 /*Umax Computer Corp*/
#define VENDOR_HERCULES2	0x4843 /*Hercules Computer Technology Inc*/
#define VENDOR_REDCREEK2	0x4916 /*RedCreek Communications Inc*/
#define VENDOR_GROWTH		0x4943 /*Growth Networks*/
#define VENDOR_ACCES		0x494f /*ACCES I/O Products, Inc.*/
#define VENDOR_AXIL		0x4978 /*Axil Computer Inc*/
#define VENDOR_NETVIN		0x4a14 /*NetVin*/
#define VENDOR_BUSLOGIC2	0x4b10 /*Buslogic Inc.*/
#define VENDOR_LUNG		0x4c48 /*LUNG HWA Electronics*/
#define VENDOR_SBS3		0x4c53 /*SBS Technologies*/
#define VENDOR_SEANIX		0x4ca1 /*Seanix Technology Inc*/
#define VENDOR_MEDIAQ		0x4d51 /*MediaQ Inc.*/
#define VENDOR_MICROTECHNICA	0x4d54 /*Microtechnica Co Ltd*/
#define VENDOR_ILC		0x4ddc /*ILC Data Device Corp*/
#define VENDOR_GEMTEK		0x5046 /*GemTek Technology Corporation*/
#define VENDOR_VOYETRA		0x5053 /*Voyetra Technologies*/
#define VENDOR_S_S		0x5136 /*S S Technologies*/
#define VENDOR_QUALCOMM		0x5143 /*Qualcomm Inc*/
#define VENDOR_ENSONIQ2		0x5145 /*Ensoniq (Old)*/
#define VENDOR_ANIMATION	0x5168 /*Animation Technologies Inc.*/
#define VENDOR_ALLIANCE3	0x5301 /*Alliance Semiconductor Corp.*/
#define VENDOR_S3_INC		0x5333 /*S3 Inc.*/
#define VENDOR_TERALOGIC	0x544c /*Teralogic Inc*/
#define VENDOR_TECHNISCHE	0x5455 /*Technische University Berlin*/
#define VENDOR_CNET2		0x5519 /*Cnet Technologies, Inc.*/
#define VENDOR_DUNORD		0x5544 /*Dunord Technologies*/
#define VENDOR_GENROCO		0x5555 /*Genroco, Inc*/
#define VENDOR_VOICETRONIX	0x5654 /*VoiceTronix Pty Ltd*/
#define VENDOR_NETPOWER2	0x5700 /*Netpower*/
#define VENDOR_EXACQ		0x5851 /*Exacq Technologies*/
#define VENDOR_ULTRASTOR	0x6356 /*UltraStor*/
#define VENDOR_C_T		0x6374 /*c't Magazin für Computertechnik*/
#define VENDOR_LOGITEC		0x6409 /*Logitec Corp.*/
#define VENDOR_DECISION		0x6666 /*Decision Computer International Co.*/
#define VENDOR_O_N		0x7604 /*O.N. Electronic Co Ltd.*/
#define VENDOR_MIDAC		0x7bde /*MIDAC Corporation*/
#define VENDOR_POWERTV		0x7fed /*PowerTV*/
#define VENDOR_QUANCOM		0x8008 /*Quancom Electronic GmbH*/
#define VENDOR_ASUSTEK2		0x807d /*Asustek Computer, Inc.*/
#define VENDOR_INTEL		0x8086 /*Intel Corp.*/
#define VENDOR_TRENDWARE	0x8401 /*TRENDware International Inc.*/
#define VENDOR_TRIGEM2		0x8800 /*Trigem Computer Inc.*/
#define VENDOR_T_SQUARE		0x8866 /*T-Square Design Inc.*/
#define VENDOR_SILICON12	0x8888 /*Silicon Magic*/
#define VENDOR_WINBOND2		0x8c4a /*Winbond*/
#define VENDOR_COMPUTONE	0x8e0e /*Computone Corporation*/
#define VENDOR_KTI		0x8e2e /*KTI*/
#define VENDOR_ADAPTEC2		0x9004 /*Adaptec*/
#define VENDOR_ADAPTEC3		0x9005 /*Adaptec*/
#define VENDOR_ATRONICS		0x907f /*Atronics*/
#define VENDOR_GIGAPIXEL	0x919a /*Gigapixel Corp*/
#define VENDOR_HOLTEK2		0x9412 /*Holtek*/
#define VENDOR_OMNI		0x9699 /*Omni Media Technology Inc*/
#define VENDOR_NETMOS		0x9710 /*NetMos Technology*/
#define VENDOR_STARGEN		0x9902 /*Stargen Inc.*/
#define VENDOR_AOPEN		0xa0a0 /*AOPEN Inc.*/
#define VENDOR_UNISYS2		0xa0f1 /*UNISYS Corporation*/
#define VENDOR_NEC3		0xa200 /*NEC Corporation*/
#define VENDOR_HEWLETT2		0xa259 /*Hewlett Packard*/
#define VENDOR_HEWLETT3		0xa25b /*Hewlett Packard GmbH PL24-MKT*/
#define VENDOR_SONY2		0xa304 /*Sony*/
#define VENDOR_3COM3		0xa727 /*3Com Corporation*/
#define VENDOR_SCITEX		0xaa42 /*Scitex Digital Video*/
#define VENDOR_DIGITAL6		0xac1e /*Digital Receiver Technology Inc*/
#define VENDOR_ACTUALITY	0xac3d /*Actuality Systems*/
#define VENDOR_ADRIENNE		0xaecb /*Adrienne Electronics Corporation*/
#define VENDOR_SHIVA2		0xb1b3 /*Shiva Europe Limited*/
#define VENDOR_PINNACLE2	0xbd11 /*Pinnacle Systems, Inc. (Wrong ID)*/
#define VENDOR_TSI		0xc001 /*TSI Telsys*/
#define VENDOR_MICRON_CRUCIAL	0xc0a9 /*Micron/Crucial Technology*/
#define VENDOR_MOTOROLA4	0xc0de /*Motorola*/
#define VENDOR_MOTION2		0xc0fe /*Motion Engineering, Inc.*/
#define VENDOR_VARIAN		0xca50 /*Varian Australia Pty Ltd*/
#define VENDOR_CHRYSALIS_ITS	0xcafe /*Chrysalis-ITS*/
#define VENDOR_CATAPULT		0xcccc /*Catapult Communications*/
#define VENDOR_TYZX		0xcddd /*Tyzx, Inc.*/
#define VENDOR_DY4		0xd4d4 /*Dy4 Systems Inc*/
#define VENDOR_I_ME		0xd531 /*I+ME ACTIA GmbH*/
#define VENDOR_EXSYS		0xd84d /*Exsys*/
#define VENDOR_INDIGITA		0xdead /*Indigita Corporation*/
#define VENDOR_WINBOND3		0xe000 /*Winbond*/
#define VENDOR_TIGER2		0xe159 /*Tiger Jet Network Inc.*/
#define VENDOR_EKF		0xe4bf /*EKF Elektronik GmbH*/
#define VENDOR_ESSENCE		0xe55e /*Essence Technology, Inc.*/
#define VENDOR_EAGLE		0xea01 /*Eagle Technology*/
#define VENDOR_RME		0xea60 /*RME*/
#define VENDOR_AASHIMA2		0xeabb /*Aashima Technology B.V.*/
#define VENDOR_ENDACE		0xeace /*Endace Measurement Systems, Ltd*/
#define VENDOR_BELKIN2		0xec80 /*Belkin Corporation*/
#define VENDOR_ECHO		0xecc0 /*Echo Digital Audio Corporation*/
#define VENDOR_ARK2		0xedd8 /*ARK Logic Inc*/
#define VENDOR_AJA		0xf1d0 /*AJA Video*/
#define VENDOR_INTERAGON	0xfa57 /*Interagon AS*/
#define VENDOR_ULTRAVIEW	0xfebd /*Ultraview Corp.*/
#define VENDOR_BROADCOM3	0xfeda /*Broadcom Inc (nee Epigram)*/
#define VENDOR_FEDETEC		0xfede /*Fedetec Inc.*/
#define VENDOR_VMWARE2		0xfffe /*VMWare Inc*/
#define VENDOR_ILLEGAL		0xffff /*Illegal Vendor ID*/

#endif/*PCI_VENDORS_INCLUDED*/
